"""
Get one application key owned by current user returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.key_management_api import KeyManagementApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = KeyManagementApi(api_client)
    response = api_instance.get_current_user_application_key(
        app_key_id="app_key_id",
    )

    print(response)



"""
Send gzip logs returns "Response from server (always 200 empty JSON)." response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.logs_api import LogsApi
from datadog_api_client.v1.model.content_encoding import ContentEncoding
from datadog_api_client.v1.model.http_log import HTTPLog
from datadog_api_client.v1.model.http_log_item import HTTPLogItem

body = HTTPLog(
    [
        HTTPLogItem(
            message="Example-Send_gzip_logs_returns_Response_from_server_always_200_empty_JSON_response",
            ddtags="host:ExampleSendgziplogsreturnsResponsefromserveralways200emptyJSONresponse",
        ),
    ]
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = LogsApi(api_client)
    response = api_instance.submit_log(content_encoding=ContentEncoding.GZIP, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class WidgetDisplayType(ModelSimple):
    """
    Type of display to use for the request.

    :param value: Must be one of ["area", "bars", "line"].
    :type value: str
    """

    allowed_values = {
        "area",
        "bars",
        "line",
    }
    AREA: ClassVar["WidgetDisplayType"]
    BARS: ClassVar["WidgetDisplayType"]
    LINE: ClassVar["WidgetDisplayType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


WidgetDisplayType.AREA = WidgetDisplayType("area")
WidgetDisplayType.BARS = WidgetDisplayType("bars")
WidgetDisplayType.LINE = WidgetDisplayType("line")



"""
Create a new dashboard with a formulas and functions treemap widget
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.formula_and_function_event_aggregation import FormulaAndFunctionEventAggregation
from datadog_api_client.v1.model.formula_and_function_event_query_definition import (
    FormulaAndFunctionEventQueryDefinition,
)
from datadog_api_client.v1.model.formula_and_function_event_query_definition_compute import (
    FormulaAndFunctionEventQueryDefinitionCompute,
)
from datadog_api_client.v1.model.formula_and_function_event_query_definition_search import (
    FormulaAndFunctionEventQueryDefinitionSearch,
)
from datadog_api_client.v1.model.formula_and_function_events_data_source import FormulaAndFunctionEventsDataSource
from datadog_api_client.v1.model.formula_and_function_response_format import FormulaAndFunctionResponseFormat
from datadog_api_client.v1.model.tree_map_widget_definition import TreeMapWidgetDefinition
from datadog_api_client.v1.model.tree_map_widget_definition_type import TreeMapWidgetDefinitionType
from datadog_api_client.v1.model.tree_map_widget_request import TreeMapWidgetRequest
from datadog_api_client.v1.model.widget import Widget
from datadog_api_client.v1.model.widget_formula import WidgetFormula
from datadog_api_client.v1.model.widget_layout import WidgetLayout

body = Dashboard(
    title="Example-Create_a_new_dashboard_with_a_formulas_and_functions_treemap_widget",
    widgets=[
        Widget(
            definition=TreeMapWidgetDefinition(
                title="",
                type=TreeMapWidgetDefinitionType.TREEMAP,
                requests=[
                    TreeMapWidgetRequest(
                        formulas=[
                            WidgetFormula(
                                formula="hour_before(query1)",
                            ),
                            WidgetFormula(
                                formula="query1",
                            ),
                        ],
                        queries=[
                            FormulaAndFunctionEventQueryDefinition(
                                data_source=FormulaAndFunctionEventsDataSource.LOGS,
                                name="query1",
                                search=FormulaAndFunctionEventQueryDefinitionSearch(
                                    query="",
                                ),
                                indexes=[
                                    "*",
                                ],
                                compute=FormulaAndFunctionEventQueryDefinitionCompute(
                                    aggregation=FormulaAndFunctionEventAggregation.COUNT,
                                ),
                                group_by=[],
                            ),
                        ],
                        response_format=FormulaAndFunctionResponseFormat.SCALAR,
                    ),
                ],
            ),
            layout=WidgetLayout(
                x=0,
                y=0,
                width=4,
                height=4,
            ),
        ),
    ],
    layout_type=DashboardLayoutType.ORDERED,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.create_dashboard(body=body)

    print(response)



"""
Create a new dashboard with note widget
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.note_widget_definition import NoteWidgetDefinition
from datadog_api_client.v1.model.note_widget_definition_type import NoteWidgetDefinitionType
from datadog_api_client.v1.model.widget import Widget
from datadog_api_client.v1.model.widget_layout import WidgetLayout

body = Dashboard(
    title="Example-Create_a_new_dashboard_with_note_widget",
    description="",
    widgets=[
        Widget(
            layout=WidgetLayout(
                x=0,
                y=0,
                width=18,
                height=24,
            ),
            definition=NoteWidgetDefinition(
                type=NoteWidgetDefinitionType.NOTE,
                content="# Example Note",
            ),
        ),
    ],
    template_variables=[],
    layout_type=DashboardLayoutType.FREE,
    is_read_only=False,
    notify_list=[],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.create_dashboard(body=body)

    print(response)



"""
Grant permission to a role returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.roles_api import RolesApi
from datadog_api_client.v2.model.permissions_type import PermissionsType
from datadog_api_client.v2.model.relationship_to_permission import RelationshipToPermission
from datadog_api_client.v2.model.relationship_to_permission_data import RelationshipToPermissionData

# there is a valid "role" in the system
ROLE_DATA_ID = environ["ROLE_DATA_ID"]

# there is a valid "permission" in the system
PERMISSION_ID = environ["PERMISSION_ID"]

body = RelationshipToPermission(
    data=RelationshipToPermissionData(
        id=PERMISSION_ID,
        type=PermissionsType.PERMISSIONS,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = RolesApi(api_client)
    response = api_instance.add_permission_to_role(role_id=ROLE_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.monitor_formula_and_function_event_aggregation import (
        MonitorFormulaAndFunctionEventAggregation,
    )


class MonitorFormulaAndFunctionEventQueryDefinitionCompute(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.monitor_formula_and_function_event_aggregation import (
            MonitorFormulaAndFunctionEventAggregation,
        )

        return {
            "aggregation": (MonitorFormulaAndFunctionEventAggregation,),
            "interval": (int,),
            "metric": (str,),
        }

    attribute_map = {
        "aggregation": "aggregation",
        "interval": "interval",
        "metric": "metric",
    }

    def __init__(
        self_,
        aggregation: MonitorFormulaAndFunctionEventAggregation,
        interval: Union[int, UnsetType] = unset,
        metric: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Compute options.

        :param aggregation: Aggregation methods for event platform queries.
        :type aggregation: MonitorFormulaAndFunctionEventAggregation

        :param interval: A time interval in milliseconds.
        :type interval: int, optional

        :param metric: Measurable attribute to compute.
        :type metric: str, optional
        """
        if interval is not unset:
            kwargs["interval"] = interval
        if metric is not unset:
            kwargs["metric"] = metric
        super().__init__(kwargs)

        self_.aggregation = aggregation



"""
Create an AWS integration returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.aws_integration_api import AWSIntegrationApi
from datadog_api_client.v1.model.aws_account import AWSAccount

body = AWSAccount(
    account_id="1234567",
    account_specific_namespace_rules=dict(
        auto_scaling=False,
        opswork=False,
    ),
    cspm_resource_collection_enabled=True,
    excluded_regions=[
        "us-east-1",
        "us-west-2",
    ],
    filter_tags=[
        "$KEY:$VALUE",
    ],
    host_tags=[
        "$KEY:$VALUE",
    ],
    metrics_collection_enabled=False,
    resource_collection_enabled=True,
    role_name="DatadogAWSIntegrationRole",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = AWSIntegrationApi(api_client)
    response = api_instance.create_aws_account(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class ProcessQueryDefinition(ModelNormal):
    validations = {
        "limit": {
            "inclusive_minimum": 0,
        },
    }

    @cached_property
    def openapi_types(_):
        return {
            "filter_by": ([str],),
            "limit": (int,),
            "metric": (str,),
            "search_by": (str,),
        }

    attribute_map = {
        "filter_by": "filter_by",
        "limit": "limit",
        "metric": "metric",
        "search_by": "search_by",
    }

    def __init__(
        self_,
        metric: str,
        filter_by: Union[List[str], UnsetType] = unset,
        limit: Union[int, UnsetType] = unset,
        search_by: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The process query to use in the widget.

        :param filter_by: List of processes.
        :type filter_by: [str], optional

        :param limit: Max number of items in the filter list.
        :type limit: int, optional

        :param metric: Your chosen metric.
        :type metric: str

        :param search_by: Your chosen search term.
        :type search_by: str, optional
        """
        if filter_by is not unset:
            kwargs["filter_by"] = filter_by
        if limit is not unset:
            kwargs["limit"] = limit
        if search_by is not unset:
            kwargs["search_by"] = search_by
        super().__init__(kwargs)

        self_.metric = metric



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class SensitiveDataScannerMetaVersionOnly(ModelNormal):
    validations = {
        "version": {
            "inclusive_minimum": 0,
        },
    }

    @cached_property
    def openapi_types(_):
        return {
            "version": (int,),
        }

    attribute_map = {
        "version": "version",
    }

    def __init__(self_, version: Union[int, UnsetType] = unset, **kwargs):
        """
        Meta payload containing information about the API.

        :param version: Version of the API (optional).
        :type version: int, optional
        """
        if version is not unset:
            kwargs["version"] = version
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_test_execution_rule import SyntheticsTestExecutionRule


class SyntheticsTestCiOptions(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_test_execution_rule import SyntheticsTestExecutionRule

        return {
            "execution_rule": (SyntheticsTestExecutionRule,),
        }

    attribute_map = {
        "execution_rule": "executionRule",
    }

    def __init__(self_, execution_rule: Union[SyntheticsTestExecutionRule, UnsetType] = unset, **kwargs):
        """
        CI/CD options for a Synthetic test.

        :param execution_rule: Execution rule for a Synthetics test.
        :type execution_rule: SyntheticsTestExecutionRule, optional
        """
        if execution_rule is not unset:
            kwargs["execution_rule"] = execution_rule
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Dict, List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.incident_field_attributes import IncidentFieldAttributes
    from datadog_api_client.v2.model.incident_timeline_cell_create_attributes import (
        IncidentTimelineCellCreateAttributes,
    )
    from datadog_api_client.v2.model.incident_notification_handle import IncidentNotificationHandle
    from datadog_api_client.v2.model.incident_field_attributes_single_value import IncidentFieldAttributesSingleValue
    from datadog_api_client.v2.model.incident_field_attributes_multiple_value import (
        IncidentFieldAttributesMultipleValue,
    )
    from datadog_api_client.v2.model.incident_timeline_cell_markdown_create_attributes import (
        IncidentTimelineCellMarkdownCreateAttributes,
    )


class IncidentCreateAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.incident_field_attributes import IncidentFieldAttributes
        from datadog_api_client.v2.model.incident_timeline_cell_create_attributes import (
            IncidentTimelineCellCreateAttributes,
        )
        from datadog_api_client.v2.model.incident_notification_handle import IncidentNotificationHandle

        return {
            "customer_impacted": (bool,),
            "fields": ({str: (IncidentFieldAttributes,)},),
            "initial_cells": ([IncidentTimelineCellCreateAttributes],),
            "notification_handles": ([IncidentNotificationHandle],),
            "title": (str,),
        }

    attribute_map = {
        "customer_impacted": "customer_impacted",
        "fields": "fields",
        "initial_cells": "initial_cells",
        "notification_handles": "notification_handles",
        "title": "title",
    }

    def __init__(
        self_,
        customer_impacted: bool,
        title: str,
        fields: Union[
            Dict[
                str,
                Union[
                    IncidentFieldAttributes, IncidentFieldAttributesSingleValue, IncidentFieldAttributesMultipleValue
                ],
            ],
            UnsetType,
        ] = unset,
        initial_cells: Union[
            List[Union[IncidentTimelineCellCreateAttributes, IncidentTimelineCellMarkdownCreateAttributes]], UnsetType
        ] = unset,
        notification_handles: Union[List[IncidentNotificationHandle], UnsetType] = unset,
        **kwargs,
    ):
        """
        The incident's attributes for a create request.

        :param customer_impacted: A flag indicating whether the incident caused customer impact.
        :type customer_impacted: bool

        :param fields: A condensed view of the user-defined fields for which to create initial selections.
        :type fields: {str: (IncidentFieldAttributes,)}, optional

        :param initial_cells: An array of initial timeline cells to be placed at the beginning of the incident timeline.
        :type initial_cells: [IncidentTimelineCellCreateAttributes], optional

        :param notification_handles: Notification handles that will be notified of the incident at creation.
        :type notification_handles: [IncidentNotificationHandle], optional

        :param title: The title of the incident, which summarizes what happened.
        :type title: str
        """
        if fields is not unset:
            kwargs["fields"] = fields
        if initial_cells is not unset:
            kwargs["initial_cells"] = initial_cells
        if notification_handles is not unset:
            kwargs["notification_handles"] = notification_handles
        super().__init__(kwargs)

        self_.customer_impacted = customer_impacted
        self_.title = title



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_exclusion_filter import LogsExclusionFilter


class LogsExclusion(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_exclusion_filter import LogsExclusionFilter

        return {
            "filter": (LogsExclusionFilter,),
            "is_enabled": (bool,),
            "name": (str,),
        }

    attribute_map = {
        "filter": "filter",
        "is_enabled": "is_enabled",
        "name": "name",
    }

    def __init__(
        self_,
        name: str,
        filter: Union[LogsExclusionFilter, UnsetType] = unset,
        is_enabled: Union[bool, UnsetType] = unset,
        **kwargs,
    ):
        """
        Represents the index exclusion filter object from configuration API.

        :param filter: Exclusion filter is defined by a query, a sampling rule, and a active/inactive toggle.
        :type filter: LogsExclusionFilter, optional

        :param is_enabled: Whether or not the exclusion filter is active.
        :type is_enabled: bool, optional

        :param name: Name of the index exclusion filter.
        :type name: str
        """
        if filter is not unset:
            kwargs["filter"] = filter
        if is_enabled is not unset:
            kwargs["is_enabled"] = is_enabled
        super().__init__(kwargs)

        self_.name = name



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class LogsPipelinesOrder(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "pipeline_ids": ([str],),
        }

    attribute_map = {
        "pipeline_ids": "pipeline_ids",
    }

    def __init__(self_, pipeline_ids: List[str], **kwargs):
        """
        Object containing the ordered list of pipeline IDs.

        :param pipeline_ids: Ordered Array of ``<PIPELINE_ID>`` strings, the order of pipeline IDs in the array
            define the overall Pipelines order for Datadog.
        :type pipeline_ids: [str]
        """
        super().__init__(kwargs)

        self_.pipeline_ids = pipeline_ids



"""
Query timeseries points returns "OK" response
"""

from datetime import datetime
from dateutil.relativedelta import relativedelta
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.metrics_api import MetricsApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = MetricsApi(api_client)
    response = api_instance.query_metrics(
        _from=int((datetime.now() + relativedelta(days=-1)).timestamp()),
        to=int(datetime.now().timestamp()),
        query="system.cpu.idle{*}",
    )

    print(response)



"""
Add resource to Confluent account returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.confluent_cloud_api import ConfluentCloudApi
from datadog_api_client.v2.model.confluent_resource_request import ConfluentResourceRequest
from datadog_api_client.v2.model.confluent_resource_request_attributes import ConfluentResourceRequestAttributes
from datadog_api_client.v2.model.confluent_resource_request_data import ConfluentResourceRequestData
from datadog_api_client.v2.model.confluent_resource_type import ConfluentResourceType

# there is a valid "confluent_account" in the system
CONFLUENT_ACCOUNT_DATA_ID = environ["CONFLUENT_ACCOUNT_DATA_ID"]

body = ConfluentResourceRequest(
    data=ConfluentResourceRequestData(
        attributes=ConfluentResourceRequestAttributes(
            resource_type="kafka",
            tags=[
                "myTag",
                "myTag2:myValue",
            ],
        ),
        id="exampleaddresourcetoconfluentaccountreturnsokresponse",
        type=ConfluentResourceType.CONFLUENT_CLOUD_RESOURCES,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ConfluentCloudApi(api_client)
    response = api_instance.create_confluent_resource(account_id=CONFLUENT_ACCOUNT_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_test_config import SyntheticsTestConfig
    from datadog_api_client.v1.model.creator import Creator
    from datadog_api_client.v1.model.synthetics_test_options import SyntheticsTestOptions
    from datadog_api_client.v1.model.synthetics_test_pause_status import SyntheticsTestPauseStatus
    from datadog_api_client.v1.model.synthetics_step import SyntheticsStep
    from datadog_api_client.v1.model.synthetics_test_details_sub_type import SyntheticsTestDetailsSubType
    from datadog_api_client.v1.model.synthetics_test_details_type import SyntheticsTestDetailsType


class SyntheticsTestDetails(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_test_config import SyntheticsTestConfig
        from datadog_api_client.v1.model.creator import Creator
        from datadog_api_client.v1.model.synthetics_test_options import SyntheticsTestOptions
        from datadog_api_client.v1.model.synthetics_test_pause_status import SyntheticsTestPauseStatus
        from datadog_api_client.v1.model.synthetics_step import SyntheticsStep
        from datadog_api_client.v1.model.synthetics_test_details_sub_type import SyntheticsTestDetailsSubType
        from datadog_api_client.v1.model.synthetics_test_details_type import SyntheticsTestDetailsType

        return {
            "config": (SyntheticsTestConfig,),
            "creator": (Creator,),
            "locations": ([str],),
            "message": (str,),
            "monitor_id": (int,),
            "name": (str,),
            "options": (SyntheticsTestOptions,),
            "public_id": (str,),
            "status": (SyntheticsTestPauseStatus,),
            "steps": ([SyntheticsStep],),
            "subtype": (SyntheticsTestDetailsSubType,),
            "tags": ([str],),
            "type": (SyntheticsTestDetailsType,),
        }

    attribute_map = {
        "config": "config",
        "creator": "creator",
        "locations": "locations",
        "message": "message",
        "monitor_id": "monitor_id",
        "name": "name",
        "options": "options",
        "public_id": "public_id",
        "status": "status",
        "steps": "steps",
        "subtype": "subtype",
        "tags": "tags",
        "type": "type",
    }
    read_only_vars = {
        "creator",
        "monitor_id",
        "public_id",
    }

    def __init__(
        self_,
        config: Union[SyntheticsTestConfig, UnsetType] = unset,
        creator: Union[Creator, UnsetType] = unset,
        locations: Union[List[str], UnsetType] = unset,
        message: Union[str, UnsetType] = unset,
        monitor_id: Union[int, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        options: Union[SyntheticsTestOptions, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        status: Union[SyntheticsTestPauseStatus, UnsetType] = unset,
        steps: Union[List[SyntheticsStep], UnsetType] = unset,
        subtype: Union[SyntheticsTestDetailsSubType, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        type: Union[SyntheticsTestDetailsType, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object containing details about your Synthetic test.

        :param config: Configuration object for a Synthetic test.
        :type config: SyntheticsTestConfig, optional

        :param creator: Object describing the creator of the shared element.
        :type creator: Creator, optional

        :param locations: Array of locations used to run the test.
        :type locations: [str], optional

        :param message: Notification message associated with the test.
        :type message: str, optional

        :param monitor_id: The associated monitor ID.
        :type monitor_id: int, optional

        :param name: Name of the test.
        :type name: str, optional

        :param options: Object describing the extra options for a Synthetic test.
        :type options: SyntheticsTestOptions, optional

        :param public_id: The test public ID.
        :type public_id: str, optional

        :param status: Define whether you want to start ( ``live`` ) or pause ( ``paused`` ) a
            Synthetic test.
        :type status: SyntheticsTestPauseStatus, optional

        :param steps: For browser test, the steps of the test.
        :type steps: [SyntheticsStep], optional

        :param subtype: The subtype of the Synthetic API test, ``http`` , ``ssl`` , ``tcp`` ,
            ``dns`` , ``icmp`` , ``udp`` , ``websocket`` , ``grpc`` or ``multi``.
        :type subtype: SyntheticsTestDetailsSubType, optional

        :param tags: Array of tags attached to the test.
        :type tags: [str], optional

        :param type: Type of the Synthetic test, either ``api`` or ``browser``.
        :type type: SyntheticsTestDetailsType, optional
        """
        if config is not unset:
            kwargs["config"] = config
        if creator is not unset:
            kwargs["creator"] = creator
        if locations is not unset:
            kwargs["locations"] = locations
        if message is not unset:
            kwargs["message"] = message
        if monitor_id is not unset:
            kwargs["monitor_id"] = monitor_id
        if name is not unset:
            kwargs["name"] = name
        if options is not unset:
            kwargs["options"] = options
        if public_id is not unset:
            kwargs["public_id"] = public_id
        if status is not unset:
            kwargs["status"] = status
        if steps is not unset:
            kwargs["steps"] = steps
        if subtype is not unset:
            kwargs["subtype"] = subtype
        if tags is not unset:
            kwargs["tags"] = tags
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SunburstWidgetLegendTableType(ModelSimple):
    """
    Whether or not to show a table legend.

    :param value: Must be one of ["table", "none"].
    :type value: str
    """

    allowed_values = {
        "table",
        "none",
    }
    TABLE: ClassVar["SunburstWidgetLegendTableType"]
    NONE: ClassVar["SunburstWidgetLegendTableType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SunburstWidgetLegendTableType.TABLE = SunburstWidgetLegendTableType("table")
SunburstWidgetLegendTableType.NONE = SunburstWidgetLegendTableType("none")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class SLOHistoryResponseErrorWithType(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "error_message": (str,),
            "error_type": (str,),
        }

    attribute_map = {
        "error_message": "error_message",
        "error_type": "error_type",
    }

    def __init__(self_, error_message: str, error_type: str, **kwargs):
        """
        An object describing the error with error type and error message.

        :param error_message: A message with more details about the error.
        :type error_message: str

        :param error_type: Type of the error.
        :type error_type: str
        """
        super().__init__(kwargs)

        self_.error_message = error_message
        self_.error_type = error_type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

import collections
from typing import Any, Dict, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    set_attribute_from_path,
    get_attribute_from_path,
    UnsetType,
    unset,
)
from datadog_api_client.v2.model.process_summaries_response import ProcessSummariesResponse
from datadog_api_client.v2.model.process_summary import ProcessSummary


class ProcessesApi:
    """
    The processes API allows you to query processes data for your organization.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._list_processes_endpoint = _Endpoint(
            settings={
                "response_type": (ProcessSummariesResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/processes",
                "operation_id": "list_processes",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "search": {
                    "openapi_types": (str,),
                    "attribute": "search",
                    "location": "query",
                },
                "tags": {
                    "openapi_types": (str,),
                    "attribute": "tags",
                    "location": "query",
                },
                "_from": {
                    "openapi_types": (int,),
                    "attribute": "from",
                    "location": "query",
                },
                "to": {
                    "openapi_types": (int,),
                    "attribute": "to",
                    "location": "query",
                },
                "page_limit": {
                    "validation": {
                        "inclusive_maximum": 10000,
                        "inclusive_minimum": 1,
                    },
                    "openapi_types": (int,),
                    "attribute": "page[limit]",
                    "location": "query",
                },
                "page_cursor": {
                    "openapi_types": (str,),
                    "attribute": "page[cursor]",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

    def list_processes(
        self,
        *,
        search: Union[str, UnsetType] = unset,
        tags: Union[str, UnsetType] = unset,
        _from: Union[int, UnsetType] = unset,
        to: Union[int, UnsetType] = unset,
        page_limit: Union[int, UnsetType] = unset,
        page_cursor: Union[str, UnsetType] = unset,
    ) -> ProcessSummariesResponse:
        """Get all processes.

        Get all processes for your organization.

        :param search: String to search processes by.
        :type search: str, optional
        :param tags: Comma-separated list of tags to filter processes by.
        :type tags: str, optional
        :param _from: Unix timestamp (number of seconds since epoch) of the start of the query window.
            If not provided, the start of the query window will be 15 minutes before the ``to`` timestamp. If neither
            ``from`` nor ``to`` are provided, the query window will be ``[now - 15m, now]``.
        :type _from: int, optional
        :param to: Unix timestamp (number of seconds since epoch) of the end of the query window.
            If not provided, the end of the query window will be 15 minutes after the ``from`` timestamp. If neither
            ``from`` nor ``to`` are provided, the query window will be ``[now - 15m, now]``.
        :type to: int, optional
        :param page_limit: Maximum number of results returned.
        :type page_limit: int, optional
        :param page_cursor: String to query the next page of results.
            This key is provided with each valid response from the API in ``meta.page.after``.
        :type page_cursor: str, optional
        :rtype: ProcessSummariesResponse
        """
        kwargs: Dict[str, Any] = {}
        if search is not unset:
            kwargs["search"] = search

        if tags is not unset:
            kwargs["tags"] = tags

        if _from is not unset:
            kwargs["_from"] = _from

        if to is not unset:
            kwargs["to"] = to

        if page_limit is not unset:
            kwargs["page_limit"] = page_limit

        if page_cursor is not unset:
            kwargs["page_cursor"] = page_cursor

        return self._list_processes_endpoint.call_with_http_info(**kwargs)

    def list_processes_with_pagination(
        self,
        *,
        search: Union[str, UnsetType] = unset,
        tags: Union[str, UnsetType] = unset,
        _from: Union[int, UnsetType] = unset,
        to: Union[int, UnsetType] = unset,
        page_limit: Union[int, UnsetType] = unset,
        page_cursor: Union[str, UnsetType] = unset,
    ) -> collections.abc.Iterable[ProcessSummary]:
        """Get all processes.

        Provide a paginated version of :meth:`list_processes`, returning all items.

        :param search: String to search processes by.
        :type search: str, optional
        :param tags: Comma-separated list of tags to filter processes by.
        :type tags: str, optional
        :param _from: Unix timestamp (number of seconds since epoch) of the start of the query window.
            If not provided, the start of the query window will be 15 minutes before the ``to`` timestamp. If neither
            ``from`` nor ``to`` are provided, the query window will be ``[now - 15m, now]``.
        :type _from: int, optional
        :param to: Unix timestamp (number of seconds since epoch) of the end of the query window.
            If not provided, the end of the query window will be 15 minutes after the ``from`` timestamp. If neither
            ``from`` nor ``to`` are provided, the query window will be ``[now - 15m, now]``.
        :type to: int, optional
        :param page_limit: Maximum number of results returned.
        :type page_limit: int, optional
        :param page_cursor: String to query the next page of results.
            This key is provided with each valid response from the API in ``meta.page.after``.
        :type page_cursor: str, optional

        :return: A generator of paginated results.
        :rtype: collections.abc.Iterable[ProcessSummary]
        """
        kwargs: Dict[str, Any] = {}
        if search is not unset:
            kwargs["search"] = search

        if tags is not unset:
            kwargs["tags"] = tags

        if _from is not unset:
            kwargs["_from"] = _from

        if to is not unset:
            kwargs["to"] = to

        if page_limit is not unset:
            kwargs["page_limit"] = page_limit

        if page_cursor is not unset:
            kwargs["page_cursor"] = page_cursor

        local_page_size = get_attribute_from_path(kwargs, "page_limit", 1000)
        endpoint = self._list_processes_endpoint
        set_attribute_from_path(kwargs, "page_limit", local_page_size, endpoint.params_map)
        while True:
            response = endpoint.call_with_http_info(**kwargs)
            for item in get_attribute_from_path(response, "data"):
                yield item
            if len(get_attribute_from_path(response, "data")) < local_page_size:
                break
            set_attribute_from_path(
                kwargs, "page_cursor", get_attribute_from_path(response, "meta.page.after"), endpoint.params_map
            )



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType


class DashboardSummaryDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType

        return {
            "author_handle": (str,),
            "created_at": (datetime,),
            "description": (str, none_type),
            "id": (str,),
            "is_read_only": (bool,),
            "layout_type": (DashboardLayoutType,),
            "modified_at": (datetime,),
            "title": (str,),
            "url": (str,),
        }

    attribute_map = {
        "author_handle": "author_handle",
        "created_at": "created_at",
        "description": "description",
        "id": "id",
        "is_read_only": "is_read_only",
        "layout_type": "layout_type",
        "modified_at": "modified_at",
        "title": "title",
        "url": "url",
    }

    def __init__(
        self_,
        author_handle: Union[str, UnsetType] = unset,
        created_at: Union[datetime, UnsetType] = unset,
        description: Union[str, none_type, UnsetType] = unset,
        id: Union[str, UnsetType] = unset,
        is_read_only: Union[bool, UnsetType] = unset,
        layout_type: Union[DashboardLayoutType, UnsetType] = unset,
        modified_at: Union[datetime, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        url: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Dashboard definition.

        :param author_handle: Identifier of the dashboard author.
        :type author_handle: str, optional

        :param created_at: Creation date of the dashboard.
        :type created_at: datetime, optional

        :param description: Description of the dashboard.
        :type description: str, none_type, optional

        :param id: Dashboard identifier.
        :type id: str, optional

        :param is_read_only: Whether this dashboard is read-only. If True, only the author and admins can make changes to it.
        :type is_read_only: bool, optional

        :param layout_type: Layout type of the dashboard.
        :type layout_type: DashboardLayoutType, optional

        :param modified_at: Modification date of the dashboard.
        :type modified_at: datetime, optional

        :param title: Title of the dashboard.
        :type title: str, optional

        :param url: URL of the dashboard.
        :type url: str, optional
        """
        if author_handle is not unset:
            kwargs["author_handle"] = author_handle
        if created_at is not unset:
            kwargs["created_at"] = created_at
        if description is not unset:
            kwargs["description"] = description
        if id is not unset:
            kwargs["id"] = id
        if is_read_only is not unset:
            kwargs["is_read_only"] = is_read_only
        if layout_type is not unset:
            kwargs["layout_type"] = layout_type
        if modified_at is not unset:
            kwargs["modified_at"] = modified_at
        if title is not unset:
            kwargs["title"] = title
        if url is not unset:
            kwargs["url"] = url
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.notebook_markdown_cell_definition_type import NotebookMarkdownCellDefinitionType


class NotebookMarkdownCellDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.notebook_markdown_cell_definition_type import (
            NotebookMarkdownCellDefinitionType,
        )

        return {
            "text": (str,),
            "type": (NotebookMarkdownCellDefinitionType,),
        }

    attribute_map = {
        "text": "text",
        "type": "type",
    }

    def __init__(self_, text: str, type: NotebookMarkdownCellDefinitionType, **kwargs):
        """
        Text in a notebook is formatted with `Markdown <https://daringfireball.net/projects/markdown/>`_ , which enables the use of headings, subheadings, links, images, lists, and code blocks.

        :param text: The markdown content.
        :type text: str

        :param type: Type of the markdown cell.
        :type type: NotebookMarkdownCellDefinitionType
        """
        super().__init__(kwargs)

        self_.text = text
        self_.type = type



"""
Create an SLO correction with rrule returns "OK" response
"""

from datetime import datetime
from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.service_level_objective_corrections_api import ServiceLevelObjectiveCorrectionsApi
from datadog_api_client.v1.model.slo_correction_category import SLOCorrectionCategory
from datadog_api_client.v1.model.slo_correction_create_data import SLOCorrectionCreateData
from datadog_api_client.v1.model.slo_correction_create_request import SLOCorrectionCreateRequest
from datadog_api_client.v1.model.slo_correction_create_request_attributes import SLOCorrectionCreateRequestAttributes
from datadog_api_client.v1.model.slo_correction_type import SLOCorrectionType

# there is a valid "slo" in the system
SLO_DATA_0_ID = environ["SLO_DATA_0_ID"]

body = SLOCorrectionCreateRequest(
    data=SLOCorrectionCreateData(
        attributes=SLOCorrectionCreateRequestAttributes(
            category=SLOCorrectionCategory.SCHEDULED_MAINTENANCE,
            description="Example-Create_an_SLO_correction_with_rrule_returns_OK_response",
            slo_id=SLO_DATA_0_ID,
            start=int(datetime.now().timestamp()),
            duration=3600,
            rrule="FREQ=DAILY;INTERVAL=10;COUNT=5",
            timezone="UTC",
        ),
        type=SLOCorrectionType.CORRECTION,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ServiceLevelObjectiveCorrectionsApi(api_client)
    response = api_instance.create_slo_correction(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SecurityMonitoringRuleNewValueOptionsLearningMethod(ModelSimple):
    """
    The learning method used to determine when signals should be generated for values that weren't learned.

    :param value: If omitted defaults to "duration". Must be one of ["duration", "threshold"].
    :type value: str
    """

    allowed_values = {
        "duration",
        "threshold",
    }
    DURATION: ClassVar["SecurityMonitoringRuleNewValueOptionsLearningMethod"]
    THRESHOLD: ClassVar["SecurityMonitoringRuleNewValueOptionsLearningMethod"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SecurityMonitoringRuleNewValueOptionsLearningMethod.DURATION = SecurityMonitoringRuleNewValueOptionsLearningMethod(
    "duration"
)
SecurityMonitoringRuleNewValueOptionsLearningMethod.THRESHOLD = SecurityMonitoringRuleNewValueOptionsLearningMethod(
    "threshold"
)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class CanceledDowntimesIds(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "cancelled_ids": ([int],),
        }

    attribute_map = {
        "cancelled_ids": "cancelled_ids",
    }

    def __init__(self_, cancelled_ids: Union[List[int], UnsetType] = unset, **kwargs):
        """
        Object containing array of IDs of canceled downtimes.

        :param cancelled_ids: ID of downtimes that were canceled.
        :type cancelled_ids: [int], optional
        """
        if cancelled_ids is not unset:
            kwargs["cancelled_ids"] = cancelled_ids
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    date,
    datetime,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.service_definition_v1_contact import ServiceDefinitionV1Contact
    from datadog_api_client.v2.model.service_definition_v1_resource import ServiceDefinitionV1Resource
    from datadog_api_client.v2.model.service_definition_v1_info import ServiceDefinitionV1Info
    from datadog_api_client.v2.model.service_definition_v1_integrations import ServiceDefinitionV1Integrations
    from datadog_api_client.v2.model.service_definition_v1_org import ServiceDefinitionV1Org
    from datadog_api_client.v2.model.service_definition_v1_version import ServiceDefinitionV1Version


class ServiceDefinitionV1(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.service_definition_v1_contact import ServiceDefinitionV1Contact
        from datadog_api_client.v2.model.service_definition_v1_resource import ServiceDefinitionV1Resource
        from datadog_api_client.v2.model.service_definition_v1_info import ServiceDefinitionV1Info
        from datadog_api_client.v2.model.service_definition_v1_integrations import ServiceDefinitionV1Integrations
        from datadog_api_client.v2.model.service_definition_v1_org import ServiceDefinitionV1Org
        from datadog_api_client.v2.model.service_definition_v1_version import ServiceDefinitionV1Version

        return {
            "contact": (ServiceDefinitionV1Contact,),
            "extensions": (
                {
                    str: (
                        bool,
                        date,
                        datetime,
                        dict,
                        float,
                        int,
                        list,
                        str,
                        none_type,
                    )
                },
            ),
            "external_resources": ([ServiceDefinitionV1Resource],),
            "info": (ServiceDefinitionV1Info,),
            "integrations": (ServiceDefinitionV1Integrations,),
            "org": (ServiceDefinitionV1Org,),
            "schema_version": (ServiceDefinitionV1Version,),
            "tags": ([str],),
        }

    attribute_map = {
        "contact": "contact",
        "extensions": "extensions",
        "external_resources": "external-resources",
        "info": "info",
        "integrations": "integrations",
        "org": "org",
        "schema_version": "schema-version",
        "tags": "tags",
    }

    def __init__(
        self_,
        info: ServiceDefinitionV1Info,
        schema_version: ServiceDefinitionV1Version,
        contact: Union[ServiceDefinitionV1Contact, UnsetType] = unset,
        extensions: Union[Dict[str, Any], UnsetType] = unset,
        external_resources: Union[List[ServiceDefinitionV1Resource], UnsetType] = unset,
        integrations: Union[ServiceDefinitionV1Integrations, UnsetType] = unset,
        org: Union[ServiceDefinitionV1Org, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        **kwargs,
    ):
        """
        Deprecated - Service definition V1 for providing additional service metadata and integrations.

        :param contact: Contact information about the service.
        :type contact: ServiceDefinitionV1Contact, optional

        :param extensions: Extensions to V1 schema.
        :type extensions: {str: (bool, date, datetime, dict, float, int, list, str, none_type,)}, optional

        :param external_resources: A list of external links related to the services.
        :type external_resources: [ServiceDefinitionV1Resource], optional

        :param info: Basic information about a service.
        :type info: ServiceDefinitionV1Info

        :param integrations: Third party integrations that Datadog supports.
        :type integrations: ServiceDefinitionV1Integrations, optional

        :param org: Org related information about the service.
        :type org: ServiceDefinitionV1Org, optional

        :param schema_version: Schema version being used.
        :type schema_version: ServiceDefinitionV1Version

        :param tags: A set of custom tags.
        :type tags: [str], optional
        """
        if contact is not unset:
            kwargs["contact"] = contact
        if extensions is not unset:
            kwargs["extensions"] = extensions
        if external_resources is not unset:
            kwargs["external_resources"] = external_resources
        if integrations is not unset:
            kwargs["integrations"] = integrations
        if org is not unset:
            kwargs["org"] = org
        if tags is not unset:
            kwargs["tags"] = tags
        super().__init__(kwargs)

        self_.info = info
        self_.schema_version = schema_version



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.organization_settings_saml import OrganizationSettingsSaml
    from datadog_api_client.v1.model.access_role import AccessRole
    from datadog_api_client.v1.model.organization_settings_saml_autocreate_users_domains import (
        OrganizationSettingsSamlAutocreateUsersDomains,
    )
    from datadog_api_client.v1.model.organization_settings_saml_idp_initiated_login import (
        OrganizationSettingsSamlIdpInitiatedLogin,
    )
    from datadog_api_client.v1.model.organization_settings_saml_strict_mode import OrganizationSettingsSamlStrictMode


class OrganizationSettings(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.organization_settings_saml import OrganizationSettingsSaml
        from datadog_api_client.v1.model.access_role import AccessRole
        from datadog_api_client.v1.model.organization_settings_saml_autocreate_users_domains import (
            OrganizationSettingsSamlAutocreateUsersDomains,
        )
        from datadog_api_client.v1.model.organization_settings_saml_idp_initiated_login import (
            OrganizationSettingsSamlIdpInitiatedLogin,
        )
        from datadog_api_client.v1.model.organization_settings_saml_strict_mode import (
            OrganizationSettingsSamlStrictMode,
        )

        return {
            "private_widget_share": (bool,),
            "saml": (OrganizationSettingsSaml,),
            "saml_autocreate_access_role": (AccessRole,),
            "saml_autocreate_users_domains": (OrganizationSettingsSamlAutocreateUsersDomains,),
            "saml_can_be_enabled": (bool,),
            "saml_idp_endpoint": (str,),
            "saml_idp_initiated_login": (OrganizationSettingsSamlIdpInitiatedLogin,),
            "saml_idp_metadata_uploaded": (bool,),
            "saml_login_url": (str,),
            "saml_strict_mode": (OrganizationSettingsSamlStrictMode,),
        }

    attribute_map = {
        "private_widget_share": "private_widget_share",
        "saml": "saml",
        "saml_autocreate_access_role": "saml_autocreate_access_role",
        "saml_autocreate_users_domains": "saml_autocreate_users_domains",
        "saml_can_be_enabled": "saml_can_be_enabled",
        "saml_idp_endpoint": "saml_idp_endpoint",
        "saml_idp_initiated_login": "saml_idp_initiated_login",
        "saml_idp_metadata_uploaded": "saml_idp_metadata_uploaded",
        "saml_login_url": "saml_login_url",
        "saml_strict_mode": "saml_strict_mode",
    }

    def __init__(
        self_,
        private_widget_share: Union[bool, UnsetType] = unset,
        saml: Union[OrganizationSettingsSaml, UnsetType] = unset,
        saml_autocreate_access_role: Union[AccessRole, UnsetType] = unset,
        saml_autocreate_users_domains: Union[OrganizationSettingsSamlAutocreateUsersDomains, UnsetType] = unset,
        saml_can_be_enabled: Union[bool, UnsetType] = unset,
        saml_idp_endpoint: Union[str, UnsetType] = unset,
        saml_idp_initiated_login: Union[OrganizationSettingsSamlIdpInitiatedLogin, UnsetType] = unset,
        saml_idp_metadata_uploaded: Union[bool, UnsetType] = unset,
        saml_login_url: Union[str, UnsetType] = unset,
        saml_strict_mode: Union[OrganizationSettingsSamlStrictMode, UnsetType] = unset,
        **kwargs,
    ):
        """
        A JSON array of settings.

        :param private_widget_share: Whether or not the organization users can share widgets outside of Datadog.
        :type private_widget_share: bool, optional

        :param saml: Set the boolean property enabled to enable or disable single sign on with SAML.
            See the SAML documentation for more information about all SAML settings.
        :type saml: OrganizationSettingsSaml, optional

        :param saml_autocreate_access_role: The access role of the user. Options are **st** (standard user), **adm** (admin user), or **ro** (read-only user).
        :type saml_autocreate_access_role: AccessRole, optional

        :param saml_autocreate_users_domains: Has two properties, ``enabled`` (boolean) and ``domains`` , which is a list of domains without the @ symbol.
        :type saml_autocreate_users_domains: OrganizationSettingsSamlAutocreateUsersDomains, optional

        :param saml_can_be_enabled: Whether or not SAML can be enabled for this organization.
        :type saml_can_be_enabled: bool, optional

        :param saml_idp_endpoint: Identity provider endpoint for SAML authentication.
        :type saml_idp_endpoint: str, optional

        :param saml_idp_initiated_login: Has one property enabled (boolean).
        :type saml_idp_initiated_login: OrganizationSettingsSamlIdpInitiatedLogin, optional

        :param saml_idp_metadata_uploaded: Whether or not a SAML identity provider metadata file was provided to the Datadog organization.
        :type saml_idp_metadata_uploaded: bool, optional

        :param saml_login_url: URL for SAML logging.
        :type saml_login_url: str, optional

        :param saml_strict_mode: Has one property enabled (boolean).
        :type saml_strict_mode: OrganizationSettingsSamlStrictMode, optional
        """
        if private_widget_share is not unset:
            kwargs["private_widget_share"] = private_widget_share
        if saml is not unset:
            kwargs["saml"] = saml
        if saml_autocreate_access_role is not unset:
            kwargs["saml_autocreate_access_role"] = saml_autocreate_access_role
        if saml_autocreate_users_domains is not unset:
            kwargs["saml_autocreate_users_domains"] = saml_autocreate_users_domains
        if saml_can_be_enabled is not unset:
            kwargs["saml_can_be_enabled"] = saml_can_be_enabled
        if saml_idp_endpoint is not unset:
            kwargs["saml_idp_endpoint"] = saml_idp_endpoint
        if saml_idp_initiated_login is not unset:
            kwargs["saml_idp_initiated_login"] = saml_idp_initiated_login
        if saml_idp_metadata_uploaded is not unset:
            kwargs["saml_idp_metadata_uploaded"] = saml_idp_metadata_uploaded
        if saml_login_url is not unset:
            kwargs["saml_login_url"] = saml_login_url
        if saml_strict_mode is not unset:
            kwargs["saml_strict_mode"] = saml_strict_mode
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_message_display import WidgetMessageDisplay
    from datadog_api_client.v1.model.widget_field_sort import WidgetFieldSort
    from datadog_api_client.v1.model.widget_time import WidgetTime
    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
    from datadog_api_client.v1.model.log_stream_widget_definition_type import LogStreamWidgetDefinitionType


class LogStreamWidgetDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_message_display import WidgetMessageDisplay
        from datadog_api_client.v1.model.widget_field_sort import WidgetFieldSort
        from datadog_api_client.v1.model.widget_time import WidgetTime
        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
        from datadog_api_client.v1.model.log_stream_widget_definition_type import LogStreamWidgetDefinitionType

        return {
            "columns": ([str],),
            "indexes": ([str],),
            "logset": (str,),
            "message_display": (WidgetMessageDisplay,),
            "query": (str,),
            "show_date_column": (bool,),
            "show_message_column": (bool,),
            "sort": (WidgetFieldSort,),
            "time": (WidgetTime,),
            "title": (str,),
            "title_align": (WidgetTextAlign,),
            "title_size": (str,),
            "type": (LogStreamWidgetDefinitionType,),
        }

    attribute_map = {
        "columns": "columns",
        "indexes": "indexes",
        "logset": "logset",
        "message_display": "message_display",
        "query": "query",
        "show_date_column": "show_date_column",
        "show_message_column": "show_message_column",
        "sort": "sort",
        "time": "time",
        "title": "title",
        "title_align": "title_align",
        "title_size": "title_size",
        "type": "type",
    }

    def __init__(
        self_,
        type: LogStreamWidgetDefinitionType,
        columns: Union[List[str], UnsetType] = unset,
        indexes: Union[List[str], UnsetType] = unset,
        logset: Union[str, UnsetType] = unset,
        message_display: Union[WidgetMessageDisplay, UnsetType] = unset,
        query: Union[str, UnsetType] = unset,
        show_date_column: Union[bool, UnsetType] = unset,
        show_message_column: Union[bool, UnsetType] = unset,
        sort: Union[WidgetFieldSort, UnsetType] = unset,
        time: Union[WidgetTime, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        title_align: Union[WidgetTextAlign, UnsetType] = unset,
        title_size: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The Log Stream displays a log flow matching the defined query. Only available on FREE layout dashboards.

        :param columns: Which columns to display on the widget.
        :type columns: [str], optional

        :param indexes: An array of index names to query in the stream. Use [] to query all indexes at once.
        :type indexes: [str], optional

        :param logset: ID of the log set to use. **Deprecated**.
        :type logset: str, optional

        :param message_display: Amount of log lines to display
        :type message_display: WidgetMessageDisplay, optional

        :param query: Query to filter the log stream with.
        :type query: str, optional

        :param show_date_column: Whether to show the date column or not
        :type show_date_column: bool, optional

        :param show_message_column: Whether to show the message column or not
        :type show_message_column: bool, optional

        :param sort: Which column and order to sort by
        :type sort: WidgetFieldSort, optional

        :param time: Time setting for the widget.
        :type time: WidgetTime, optional

        :param title: Title of the widget.
        :type title: str, optional

        :param title_align: How to align the text on the widget.
        :type title_align: WidgetTextAlign, optional

        :param title_size: Size of the title.
        :type title_size: str, optional

        :param type: Type of the log stream widget.
        :type type: LogStreamWidgetDefinitionType
        """
        if columns is not unset:
            kwargs["columns"] = columns
        if indexes is not unset:
            kwargs["indexes"] = indexes
        if logset is not unset:
            kwargs["logset"] = logset
        if message_display is not unset:
            kwargs["message_display"] = message_display
        if query is not unset:
            kwargs["query"] = query
        if show_date_column is not unset:
            kwargs["show_date_column"] = show_date_column
        if show_message_column is not unset:
            kwargs["show_message_column"] = show_message_column
        if sort is not unset:
            kwargs["sort"] = sort
        if time is not unset:
            kwargs["time"] = time
        if title is not unset:
            kwargs["title"] = title
        if title_align is not unset:
            kwargs["title_align"] = title_align
        if title_size is not unset:
            kwargs["title_size"] = title_size
        super().__init__(kwargs)

        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Dict, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.rum_aggregate_bucket_value import RUMAggregateBucketValue
    from datadog_api_client.v2.model.rum_aggregate_bucket_value_timeseries import RUMAggregateBucketValueTimeseries


class RUMBucketResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.rum_aggregate_bucket_value import RUMAggregateBucketValue

        return {
            "by": ({str: (str,)},),
            "computes": ({str: (RUMAggregateBucketValue,)},),
        }

    attribute_map = {
        "by": "by",
        "computes": "computes",
    }

    def __init__(
        self_,
        by: Union[Dict[str, str], UnsetType] = unset,
        computes: Union[
            Dict[str, Union[RUMAggregateBucketValue, str, float, RUMAggregateBucketValueTimeseries]], UnsetType
        ] = unset,
        **kwargs,
    ):
        """
        Bucket values.

        :param by: The key-value pairs for each group-by.
        :type by: {str: (str,)}, optional

        :param computes: A map of the metric name to value for regular compute, or a list of values for a timeseries.
        :type computes: {str: (RUMAggregateBucketValue,)}, optional
        """
        if by is not unset:
            kwargs["by"] = by
        if computes is not unset:
            kwargs["computes"] = computes
        super().__init__(kwargs)



"""
Update a single service object returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.opsgenie_integration_api import OpsgenieIntegrationApi
from datadog_api_client.v2.model.opsgenie_service_region_type import OpsgenieServiceRegionType
from datadog_api_client.v2.model.opsgenie_service_type import OpsgenieServiceType
from datadog_api_client.v2.model.opsgenie_service_update_attributes import OpsgenieServiceUpdateAttributes
from datadog_api_client.v2.model.opsgenie_service_update_data import OpsgenieServiceUpdateData
from datadog_api_client.v2.model.opsgenie_service_update_request import OpsgenieServiceUpdateRequest

# there is a valid "opsgenie_service" in the system
OPSGENIE_SERVICE_DATA_ATTRIBUTES_NAME = environ["OPSGENIE_SERVICE_DATA_ATTRIBUTES_NAME"]
OPSGENIE_SERVICE_DATA_ID = environ["OPSGENIE_SERVICE_DATA_ID"]

body = OpsgenieServiceUpdateRequest(
    data=OpsgenieServiceUpdateData(
        attributes=OpsgenieServiceUpdateAttributes(
            name="fake-opsgenie-service-name--updated",
            opsgenie_api_key="00000000-0000-0000-0000-000000000000",
            region=OpsgenieServiceRegionType.EU,
        ),
        id=OPSGENIE_SERVICE_DATA_ID,
        type=OpsgenieServiceType.OPSGENIE_SERVICE,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = OpsgenieIntegrationApi(api_client)
    response = api_instance.update_opsgenie_service(integration_service_id=OPSGENIE_SERVICE_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.dashboard_list_item_response import DashboardListItemResponse


class DashboardListDeleteItemsResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.dashboard_list_item_response import DashboardListItemResponse

        return {
            "deleted_dashboards_from_list": ([DashboardListItemResponse],),
        }

    attribute_map = {
        "deleted_dashboards_from_list": "deleted_dashboards_from_list",
    }

    def __init__(
        self_, deleted_dashboards_from_list: Union[List[DashboardListItemResponse], UnsetType] = unset, **kwargs
    ):
        """
        Response containing a list of deleted dashboards.

        :param deleted_dashboards_from_list: List of dashboards deleted from the dashboard list.
        :type deleted_dashboards_from_list: [DashboardListItemResponse], optional
        """
        if deleted_dashboards_from_list is not unset:
            kwargs["deleted_dashboards_from_list"] = deleted_dashboards_from_list
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.sensitive_data_scanner_configuration_relationships import (
        SensitiveDataScannerConfigurationRelationships,
    )
    from datadog_api_client.v2.model.sensitive_data_scanner_configuration_type import (
        SensitiveDataScannerConfigurationType,
    )


class SensitiveDataScannerGetConfigResponseData(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.sensitive_data_scanner_configuration_relationships import (
            SensitiveDataScannerConfigurationRelationships,
        )
        from datadog_api_client.v2.model.sensitive_data_scanner_configuration_type import (
            SensitiveDataScannerConfigurationType,
        )

        return {
            "id": (str,),
            "relationships": (SensitiveDataScannerConfigurationRelationships,),
            "type": (SensitiveDataScannerConfigurationType,),
        }

    attribute_map = {
        "id": "id",
        "relationships": "relationships",
        "type": "type",
    }

    def __init__(
        self_,
        id: Union[str, UnsetType] = unset,
        relationships: Union[SensitiveDataScannerConfigurationRelationships, UnsetType] = unset,
        type: Union[SensitiveDataScannerConfigurationType, UnsetType] = unset,
        **kwargs,
    ):
        """
        Response data related to the scanning groups.

        :param id: ID of the configuration.
        :type id: str, optional

        :param relationships: Relationships of the configuration.
        :type relationships: SensitiveDataScannerConfigurationRelationships, optional

        :param type: Sensitive Data Scanner configuration type.
        :type type: SensitiveDataScannerConfigurationType, optional
        """
        if id is not unset:
            kwargs["id"] = id
        if relationships is not unset:
            kwargs["relationships"] = relationships
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)



"""
Get a signal's details returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SecurityMonitoringApi(api_client)
    response = api_instance.get_security_monitoring_signal(
        signal_id="AQAAAYNqUBVU4-rffwAAAABBWU5xVUJWVUFBQjJBd3ptMDdQUnF3QUE",
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.v1.model.successful_signal_update_response import SuccessfulSignalUpdateResponse
from datadog_api_client.v1.model.add_signal_to_incident_request import AddSignalToIncidentRequest
from datadog_api_client.v1.model.signal_assignee_update_request import SignalAssigneeUpdateRequest
from datadog_api_client.v1.model.signal_state_update_request import SignalStateUpdateRequest


class SecurityMonitoringApi:
    """
    Detection rules for generating signals and listing of generated
    signals.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._add_security_monitoring_signal_to_incident_endpoint = _Endpoint(
            settings={
                "response_type": (SuccessfulSignalUpdateResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/security_analytics/signals/{signal_id}/add_to_incident",
                "operation_id": "add_security_monitoring_signal_to_incident",
                "http_method": "PATCH",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "signal_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "signal_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (AddSignalToIncidentRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._edit_security_monitoring_signal_assignee_endpoint = _Endpoint(
            settings={
                "response_type": (SuccessfulSignalUpdateResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/security_analytics/signals/{signal_id}/assignee",
                "operation_id": "edit_security_monitoring_signal_assignee",
                "http_method": "PATCH",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "signal_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "signal_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (SignalAssigneeUpdateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._edit_security_monitoring_signal_state_endpoint = _Endpoint(
            settings={
                "response_type": (SuccessfulSignalUpdateResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/security_analytics/signals/{signal_id}/state",
                "operation_id": "edit_security_monitoring_signal_state",
                "http_method": "PATCH",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "signal_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "signal_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (SignalStateUpdateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def add_security_monitoring_signal_to_incident(
        self,
        signal_id: str,
        body: AddSignalToIncidentRequest,
    ) -> SuccessfulSignalUpdateResponse:
        """Add a security signal to an incident.

        Add a security signal to an incident. This makes it possible to search for signals by incident within the signal explorer and to view the signals on the incident timeline.

        :param signal_id: The ID of the signal.
        :type signal_id: str
        :param body: Attributes describing the signal update.
        :type body: AddSignalToIncidentRequest
        :rtype: SuccessfulSignalUpdateResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["signal_id"] = signal_id

        kwargs["body"] = body

        return self._add_security_monitoring_signal_to_incident_endpoint.call_with_http_info(**kwargs)

    def edit_security_monitoring_signal_assignee(
        self,
        signal_id: str,
        body: SignalAssigneeUpdateRequest,
    ) -> SuccessfulSignalUpdateResponse:
        """Modify the triage assignee of a security signal.

        Modify the triage assignee of a security signal.

        :param signal_id: The ID of the signal.
        :type signal_id: str
        :param body: Attributes describing the signal update.
        :type body: SignalAssigneeUpdateRequest
        :rtype: SuccessfulSignalUpdateResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["signal_id"] = signal_id

        kwargs["body"] = body

        return self._edit_security_monitoring_signal_assignee_endpoint.call_with_http_info(**kwargs)

    def edit_security_monitoring_signal_state(
        self,
        signal_id: str,
        body: SignalStateUpdateRequest,
    ) -> SuccessfulSignalUpdateResponse:
        """Change the triage state of a security signal.

        Change the triage state of a security signal.

        :param signal_id: The ID of the signal.
        :type signal_id: str
        :param body: Attributes describing the signal update.
        :type body: SignalStateUpdateRequest
        :rtype: SuccessfulSignalUpdateResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["signal_id"] = signal_id

        kwargs["body"] = body

        return self._edit_security_monitoring_signal_state_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class ListStreamSource(ModelSimple):
    """
    Source from which to query items to display in the stream.

    :param value: If omitted defaults to "apm_issue_stream". Must be one of ["logs_stream", "audit_stream", "rum_issue_stream", "apm_issue_stream", "logs_pattern_stream"].
    :type value: str
    """

    allowed_values = {
        "logs_stream",
        "audit_stream",
        "rum_issue_stream",
        "apm_issue_stream",
        "logs_pattern_stream",
    }
    LOGS_STREAM: ClassVar["ListStreamSource"]
    AUDIT_STREAM: ClassVar["ListStreamSource"]
    RUM_ISSUE_STREAM: ClassVar["ListStreamSource"]
    APM_ISSUE_STREAM: ClassVar["ListStreamSource"]
    LOGS_PATTERN_STREAM: ClassVar["ListStreamSource"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


ListStreamSource.LOGS_STREAM = ListStreamSource("logs_stream")
ListStreamSource.AUDIT_STREAM = ListStreamSource("audit_stream")
ListStreamSource.RUM_ISSUE_STREAM = ListStreamSource("rum_issue_stream")
ListStreamSource.APM_ISSUE_STREAM = ListStreamSource("apm_issue_stream")
ListStreamSource.LOGS_PATTERN_STREAM = ListStreamSource("logs_pattern_stream")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SecurityMonitoringRuleQueryAggregation(ModelSimple):
    """
    The aggregation type.

    :param value: Must be one of ["count", "cardinality", "sum", "max", "new_value", "geo_data", "event_count"].
    :type value: str
    """

    allowed_values = {
        "count",
        "cardinality",
        "sum",
        "max",
        "new_value",
        "geo_data",
        "event_count",
    }
    COUNT: ClassVar["SecurityMonitoringRuleQueryAggregation"]
    CARDINALITY: ClassVar["SecurityMonitoringRuleQueryAggregation"]
    SUM: ClassVar["SecurityMonitoringRuleQueryAggregation"]
    MAX: ClassVar["SecurityMonitoringRuleQueryAggregation"]
    NEW_VALUE: ClassVar["SecurityMonitoringRuleQueryAggregation"]
    GEO_DATA: ClassVar["SecurityMonitoringRuleQueryAggregation"]
    EVENT_COUNT: ClassVar["SecurityMonitoringRuleQueryAggregation"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SecurityMonitoringRuleQueryAggregation.COUNT = SecurityMonitoringRuleQueryAggregation("count")
SecurityMonitoringRuleQueryAggregation.CARDINALITY = SecurityMonitoringRuleQueryAggregation("cardinality")
SecurityMonitoringRuleQueryAggregation.SUM = SecurityMonitoringRuleQueryAggregation("sum")
SecurityMonitoringRuleQueryAggregation.MAX = SecurityMonitoringRuleQueryAggregation("max")
SecurityMonitoringRuleQueryAggregation.NEW_VALUE = SecurityMonitoringRuleQueryAggregation("new_value")
SecurityMonitoringRuleQueryAggregation.GEO_DATA = SecurityMonitoringRuleQueryAggregation("geo_data")
SecurityMonitoringRuleQueryAggregation.EVENT_COUNT = SecurityMonitoringRuleQueryAggregation("event_count")



"""
Get host tags returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.tags_api import TagsApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = TagsApi(api_client)
    response = api_instance.get_host_tags(
        host_name="host_name",
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    file_type,
    UnsetType,
    unset,
)


class OrganizationsApi:
    """
    Create, edit, and manage your organizations. Read more about `multi-org accounts <https://docs.datadoghq.com/account_management/multi_organization>`_.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._upload_idp_metadata_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/saml_configurations/idp_metadata",
                "operation_id": "upload_idp_metadata",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "idp_file": {
                    "openapi_types": (file_type,),
                    "attribute": "idp_file",
                    "location": "form",
                },
            },
            headers_map={"accept": ["*/*"], "content_type": ["multipart/form-data"]},
            api_client=api_client,
        )

    def upload_idp_metadata(
        self,
        *,
        idp_file: Union[file_type, UnsetType] = unset,
    ) -> None:
        """Upload IdP metadata.

        Endpoint for uploading IdP metadata for SAML setup.

        Use this endpoint to upload or replace IdP metadata for SAML login configuration.

        :param idp_file: The IdP metadata XML file
        :type idp_file: file_type, optional
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        if idp_file is not unset:
            kwargs["idp_file"] = idp_file

        return self._upload_idp_metadata_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


class UsageHostHour(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "agent_host_count": (int,),
            "alibaba_host_count": (int,),
            "apm_azure_app_service_host_count": (int,),
            "apm_host_count": (int,),
            "aws_host_count": (int,),
            "azure_host_count": (int,),
            "container_count": (int,),
            "gcp_host_count": (int,),
            "heroku_host_count": (int,),
            "host_count": (int,),
            "hour": (datetime,),
            "infra_azure_app_service": (int,),
            "opentelemetry_apm_host_count": (int,),
            "opentelemetry_host_count": (int,),
            "org_name": (str,),
            "public_id": (str,),
            "vsphere_host_count": (int,),
        }

    attribute_map = {
        "agent_host_count": "agent_host_count",
        "alibaba_host_count": "alibaba_host_count",
        "apm_azure_app_service_host_count": "apm_azure_app_service_host_count",
        "apm_host_count": "apm_host_count",
        "aws_host_count": "aws_host_count",
        "azure_host_count": "azure_host_count",
        "container_count": "container_count",
        "gcp_host_count": "gcp_host_count",
        "heroku_host_count": "heroku_host_count",
        "host_count": "host_count",
        "hour": "hour",
        "infra_azure_app_service": "infra_azure_app_service",
        "opentelemetry_apm_host_count": "opentelemetry_apm_host_count",
        "opentelemetry_host_count": "opentelemetry_host_count",
        "org_name": "org_name",
        "public_id": "public_id",
        "vsphere_host_count": "vsphere_host_count",
    }

    def __init__(
        self_,
        agent_host_count: Union[int, UnsetType] = unset,
        alibaba_host_count: Union[int, UnsetType] = unset,
        apm_azure_app_service_host_count: Union[int, UnsetType] = unset,
        apm_host_count: Union[int, UnsetType] = unset,
        aws_host_count: Union[int, UnsetType] = unset,
        azure_host_count: Union[int, UnsetType] = unset,
        container_count: Union[int, UnsetType] = unset,
        gcp_host_count: Union[int, UnsetType] = unset,
        heroku_host_count: Union[int, UnsetType] = unset,
        host_count: Union[int, UnsetType] = unset,
        hour: Union[datetime, UnsetType] = unset,
        infra_azure_app_service: Union[int, UnsetType] = unset,
        opentelemetry_apm_host_count: Union[int, UnsetType] = unset,
        opentelemetry_host_count: Union[int, UnsetType] = unset,
        org_name: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        vsphere_host_count: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        Number of hosts/containers recorded for each hour for a given organization.

        :param agent_host_count: Contains the total number of infrastructure hosts reporting
            during a given hour that were running the Datadog Agent.
        :type agent_host_count: int, optional

        :param alibaba_host_count: Contains the total number of hosts that reported through Alibaba integration
            (and were NOT running the Datadog Agent).
        :type alibaba_host_count: int, optional

        :param apm_azure_app_service_host_count: Contains the total number of Azure App Services hosts using APM.
        :type apm_azure_app_service_host_count: int, optional

        :param apm_host_count: Shows the total number of hosts using APM during the hour,
            these are counted as billable (except during trial periods).
        :type apm_host_count: int, optional

        :param aws_host_count: Contains the total number of hosts that reported through the AWS integration
            (and were NOT running the Datadog Agent).
        :type aws_host_count: int, optional

        :param azure_host_count: Contains the total number of hosts that reported through Azure integration
            (and were NOT running the Datadog Agent).
        :type azure_host_count: int, optional

        :param container_count: Shows the total number of containers reported by the Docker integration during the hour.
        :type container_count: int, optional

        :param gcp_host_count: Contains the total number of hosts that reported through the Google Cloud integration
            (and were NOT running the Datadog Agent).
        :type gcp_host_count: int, optional

        :param heroku_host_count: Contains the total number of Heroku dynos reported by the Datadog Agent.
        :type heroku_host_count: int, optional

        :param host_count: Contains the total number of billable infrastructure hosts reporting during a given hour.
            This is the sum of ``agent_host_count`` , ``aws_host_count`` , and ``gcp_host_count``.
        :type host_count: int, optional

        :param hour: The hour for the usage.
        :type hour: datetime, optional

        :param infra_azure_app_service: Contains the total number of hosts that reported through the Azure App Services integration
            (and were NOT running the Datadog Agent).
        :type infra_azure_app_service: int, optional

        :param opentelemetry_apm_host_count: Contains the total number of hosts using APM reported by Datadog exporter for the OpenTelemetry Collector.
        :type opentelemetry_apm_host_count: int, optional

        :param opentelemetry_host_count: Contains the total number of hosts reported by Datadog exporter for the OpenTelemetry Collector.
        :type opentelemetry_host_count: int, optional

        :param org_name: The organization name.
        :type org_name: str, optional

        :param public_id: The organization public ID.
        :type public_id: str, optional

        :param vsphere_host_count: Contains the total number of hosts that reported through vSphere integration
            (and were NOT running the Datadog Agent).
        :type vsphere_host_count: int, optional
        """
        if agent_host_count is not unset:
            kwargs["agent_host_count"] = agent_host_count
        if alibaba_host_count is not unset:
            kwargs["alibaba_host_count"] = alibaba_host_count
        if apm_azure_app_service_host_count is not unset:
            kwargs["apm_azure_app_service_host_count"] = apm_azure_app_service_host_count
        if apm_host_count is not unset:
            kwargs["apm_host_count"] = apm_host_count
        if aws_host_count is not unset:
            kwargs["aws_host_count"] = aws_host_count
        if azure_host_count is not unset:
            kwargs["azure_host_count"] = azure_host_count
        if container_count is not unset:
            kwargs["container_count"] = container_count
        if gcp_host_count is not unset:
            kwargs["gcp_host_count"] = gcp_host_count
        if heroku_host_count is not unset:
            kwargs["heroku_host_count"] = heroku_host_count
        if host_count is not unset:
            kwargs["host_count"] = host_count
        if hour is not unset:
            kwargs["hour"] = hour
        if infra_azure_app_service is not unset:
            kwargs["infra_azure_app_service"] = infra_azure_app_service
        if opentelemetry_apm_host_count is not unset:
            kwargs["opentelemetry_apm_host_count"] = opentelemetry_apm_host_count
        if opentelemetry_host_count is not unset:
            kwargs["opentelemetry_host_count"] = opentelemetry_host_count
        if org_name is not unset:
            kwargs["org_name"] = org_name
        if public_id is not unset:
            kwargs["public_id"] = public_id
        if vsphere_host_count is not unset:
            kwargs["vsphere_host_count"] = vsphere_host_count
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


class UsageTimeseriesHour(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "hour": (datetime,),
            "num_custom_input_timeseries": (int,),
            "num_custom_output_timeseries": (int,),
            "num_custom_timeseries": (int,),
            "org_name": (str,),
            "public_id": (str,),
        }

    attribute_map = {
        "hour": "hour",
        "num_custom_input_timeseries": "num_custom_input_timeseries",
        "num_custom_output_timeseries": "num_custom_output_timeseries",
        "num_custom_timeseries": "num_custom_timeseries",
        "org_name": "org_name",
        "public_id": "public_id",
    }

    def __init__(
        self_,
        hour: Union[datetime, UnsetType] = unset,
        num_custom_input_timeseries: Union[int, UnsetType] = unset,
        num_custom_output_timeseries: Union[int, UnsetType] = unset,
        num_custom_timeseries: Union[int, UnsetType] = unset,
        org_name: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The hourly usage of timeseries.

        :param hour: The hour for the usage.
        :type hour: datetime, optional

        :param num_custom_input_timeseries: Contains the number of custom metrics that are inputs for aggregations (metric configured is custom).
        :type num_custom_input_timeseries: int, optional

        :param num_custom_output_timeseries: Contains the number of custom metrics that are outputs for aggregations (metric configured is custom).
        :type num_custom_output_timeseries: int, optional

        :param num_custom_timeseries: Contains sum of non-aggregation custom metrics and custom metrics that are outputs for aggregations.
        :type num_custom_timeseries: int, optional

        :param org_name: The organization name.
        :type org_name: str, optional

        :param public_id: The organization public ID.
        :type public_id: str, optional
        """
        if hour is not unset:
            kwargs["hour"] = hour
        if num_custom_input_timeseries is not unset:
            kwargs["num_custom_input_timeseries"] = num_custom_input_timeseries
        if num_custom_output_timeseries is not unset:
            kwargs["num_custom_output_timeseries"] = num_custom_output_timeseries
        if num_custom_timeseries is not unset:
            kwargs["num_custom_timeseries"] = num_custom_timeseries
        if org_name is not unset:
            kwargs["org_name"] = org_name
        if public_id is not unset:
            kwargs["public_id"] = public_id
        super().__init__(kwargs)



import pathlib

import click
from jinja2 import Environment, FileSystemLoader

from . import openapi
from . import formatter

PACKAGE_NAME = "datadog_api_client"


@click.command()
@click.argument(
    "specs",
    nargs=-1,
    type=click.Path(exists=True, file_okay=True, dir_okay=False, path_type=pathlib.Path),
)
@click.option(
    "-o",
    "--output",
    type=click.Path(path_type=pathlib.Path),
)
def cli(specs, output):
    """
    Generate a Python code snippet from OpenAPI specification.
    """
    env = Environment(loader=FileSystemLoader(str(pathlib.Path(__file__).parent / "templates")))

    env.filters["accept_headers"] = openapi.accept_headers
    env.filters["attribute_name"] = formatter.attribute_name
    env.filters["camel_case"] = formatter.camel_case
    env.filters["collection_format"] = openapi.collection_format
    env.filters["format_value"] = formatter.format_value
    env.filters["attribute_path"] = formatter.attribute_path
    env.filters["parameter_schema"] = openapi.parameter_schema
    env.filters["parameters"] = openapi.parameters
    env.filters["return_type"] = openapi.return_type
    env.filters["safe_snake_case"] = formatter.safe_snake_case
    env.filters["docstring"] = formatter.docstring

    env.globals["enumerate"] = enumerate
    env.globals["package"] = PACKAGE_NAME
    env.globals["get_name"] = formatter.get_name
    env.globals["get_type_for_attribute"] = openapi.get_type_for_attribute
    env.globals["get_typing_for_attribute"] = openapi.get_typing_for_attribute
    env.globals["get_types_for_attribute"] = openapi.get_types_for_attribute
    env.globals["get_type_for_parameter"] = openapi.get_type_for_parameter
    env.globals["get_references_for_model"] = openapi.get_references_for_model
    env.globals["get_oneof_references_for_model"] = openapi.get_oneof_references_for_model
    env.globals["get_oneof_parameters"] = openapi.get_oneof_parameters
    env.globals["get_type_for_items"] = openapi.get_type_for_items
    env.globals["get_api_models"] = openapi.get_api_models
    env.globals["get_enum_type"] = openapi.get_enum_type
    env.globals["get_enum_default"] = openapi.get_enum_default
    env.globals["get_oneof_types"] = openapi.get_oneof_types
    env.globals["get_oneof_models"] = openapi.get_oneof_models
    env.globals["type_to_python"] = openapi.type_to_python
    env.globals["get_default"] = openapi.get_default
    env.globals["get_type_at_path"] = openapi.get_type_at_path

    api_j2 = env.get_template("api.j2")
    apis_j2 = env.get_template("apis.j2")
    model_j2 = env.get_template("model.j2")
    models_j2 = env.get_template("models.j2")
    init_j2 = env.get_template("init.j2")
    configuration_j2 = env.get_template("configuration.j2")

    extra_files = {
        "api_client.py": env.get_template("api_client.j2"),
        "exceptions.py": env.get_template("exceptions.j2"),
        "model_utils.py": env.get_template("model_utils.j2"),
        "rest.py": env.get_template("rest.j2"),
    }

    top_package = output / PACKAGE_NAME
    top_package.mkdir(parents=True, exist_ok=True)

    for name, template in extra_files.items():
        filename = top_package / name
        with filename.open("w") as fp:
            fp.write(template.render())

    all_specs = {}
    all_apis = {}

    for spec_path in specs:
        spec = openapi.load(spec_path)
        env.globals["openapi"] = spec

        version = spec_path.parent.name
        env.globals["version"] = version

        all_specs[version] = spec

        apis = openapi.apis(spec)
        all_apis[version] = apis
        models = openapi.models(spec)

        package = top_package / version
        package.mkdir(exist_ok=True)

        for name, model in models.items():
            filename = formatter.safe_snake_case(name) + ".py"
            model_path = package / "model" / filename
            model_path.parent.mkdir(parents=True, exist_ok=True)
            with model_path.open("w") as fp:
                fp.write(model_j2.render(name=name, model=model))

        model_init_path = package / "model" / "__init__.py"
        with model_init_path.open("w") as fp:
            fp.write("")

        models_path = package / "models" / "__init__.py"
        models_path.parent.mkdir(parents=True, exist_ok=True)
        with models_path.open("w") as fp:
            fp.write(models_j2.render(models=sorted(models)))

        tags_by_name = {tag["name"]: tag for tag in spec["tags"]}

        for name, operations in apis.items():
            filename = formatter.safe_snake_case(name) + "_api.py"
            api_path = package / "api" / filename
            api_path.parent.mkdir(parents=True, exist_ok=True)
            with api_path.open("w") as fp:
                fp.write(api_j2.render(name=name, operations=operations, description=tags_by_name[name]["description"]))

        api_init_path = package / "api" / "__init__.py"
        with api_init_path.open("w") as fp:
            fp.write("")

        apis_path = package / "apis" / "__init__.py"
        apis_path.parent.mkdir(parents=True, exist_ok=True)
        with apis_path.open("w") as fp:
            fp.write(apis_j2.render(apis=sorted(apis)))

        init_path = package / "__init__.py"
        with init_path.open("w") as fp:
            fp.write(init_j2.render())

    filename = top_package / "configuration.py"
    with filename.open("w") as fp:
        fp.write(configuration_j2.render(specs=all_specs, apis=all_apis))



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    date,
    datetime,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_browser_error import SyntheticsBrowserError
    from datadog_api_client.v1.model.synthetics_check_type import SyntheticsCheckType
    from datadog_api_client.v1.model.synthetics_playing_tab import SyntheticsPlayingTab
    from datadog_api_client.v1.model.synthetics_step_type import SyntheticsStepType
    from datadog_api_client.v1.model.synthetics_core_web_vitals import SyntheticsCoreWebVitals
    from datadog_api_client.v1.model.synthetics_step_detail_warning import SyntheticsStepDetailWarning


class SyntheticsStepDetail(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_browser_error import SyntheticsBrowserError
        from datadog_api_client.v1.model.synthetics_check_type import SyntheticsCheckType
        from datadog_api_client.v1.model.synthetics_playing_tab import SyntheticsPlayingTab
        from datadog_api_client.v1.model.synthetics_step_type import SyntheticsStepType
        from datadog_api_client.v1.model.synthetics_core_web_vitals import SyntheticsCoreWebVitals
        from datadog_api_client.v1.model.synthetics_step_detail_warning import SyntheticsStepDetailWarning

        return {
            "browser_errors": ([SyntheticsBrowserError],),
            "check_type": (SyntheticsCheckType,),
            "description": (str,),
            "duration": (float,),
            "error": (str,),
            "playing_tab": (SyntheticsPlayingTab,),
            "screenshot_bucket_key": (bool,),
            "skipped": (bool,),
            "snapshot_bucket_key": (bool,),
            "step_id": (int,),
            "sub_test_step_details": ([SyntheticsStepDetail],),
            "time_to_interactive": (float,),
            "type": (SyntheticsStepType,),
            "url": (str,),
            "value": (
                bool,
                date,
                datetime,
                dict,
                float,
                int,
                list,
                str,
                none_type,
            ),
            "vitals_metrics": ([SyntheticsCoreWebVitals],),
            "warnings": ([SyntheticsStepDetailWarning],),
        }

    attribute_map = {
        "browser_errors": "browserErrors",
        "check_type": "checkType",
        "description": "description",
        "duration": "duration",
        "error": "error",
        "playing_tab": "playingTab",
        "screenshot_bucket_key": "screenshotBucketKey",
        "skipped": "skipped",
        "snapshot_bucket_key": "snapshotBucketKey",
        "step_id": "stepId",
        "sub_test_step_details": "subTestStepDetails",
        "time_to_interactive": "timeToInteractive",
        "type": "type",
        "url": "url",
        "value": "value",
        "vitals_metrics": "vitalsMetrics",
        "warnings": "warnings",
    }

    def __init__(
        self_,
        browser_errors: Union[List[SyntheticsBrowserError], UnsetType] = unset,
        check_type: Union[SyntheticsCheckType, UnsetType] = unset,
        description: Union[str, UnsetType] = unset,
        duration: Union[float, UnsetType] = unset,
        error: Union[str, UnsetType] = unset,
        playing_tab: Union[SyntheticsPlayingTab, UnsetType] = unset,
        screenshot_bucket_key: Union[bool, UnsetType] = unset,
        skipped: Union[bool, UnsetType] = unset,
        snapshot_bucket_key: Union[bool, UnsetType] = unset,
        step_id: Union[int, UnsetType] = unset,
        sub_test_step_details: Union[List[SyntheticsStepDetail], UnsetType] = unset,
        time_to_interactive: Union[float, UnsetType] = unset,
        type: Union[SyntheticsStepType, UnsetType] = unset,
        url: Union[str, UnsetType] = unset,
        value: Union[Any, UnsetType] = unset,
        vitals_metrics: Union[List[SyntheticsCoreWebVitals], UnsetType] = unset,
        warnings: Union[List[SyntheticsStepDetailWarning], UnsetType] = unset,
        **kwargs,
    ):
        """
        Object describing a step for a Synthetic test.

        :param browser_errors: Array of errors collected for a browser test.
        :type browser_errors: [SyntheticsBrowserError], optional

        :param check_type: Type of assertion to apply in an API test.
        :type check_type: SyntheticsCheckType, optional

        :param description: Description of the test.
        :type description: str, optional

        :param duration: Total duration in millisecond of the test.
        :type duration: float, optional

        :param error: Error returned by the test.
        :type error: str, optional

        :param playing_tab: Navigate between different tabs for your browser test.
        :type playing_tab: SyntheticsPlayingTab, optional

        :param screenshot_bucket_key: Whether or not screenshots where collected by the test.
        :type screenshot_bucket_key: bool, optional

        :param skipped: Whether or not to skip this step.
        :type skipped: bool, optional

        :param snapshot_bucket_key: Whether or not snapshots where collected by the test.
        :type snapshot_bucket_key: bool, optional

        :param step_id: The step ID.
        :type step_id: int, optional

        :param sub_test_step_details: If this steps include a sub-test.
            `Subtests documentation <https://docs.datadoghq.com/synthetics/browser_tests/advanced_options/#subtests>`_.
        :type sub_test_step_details: [SyntheticsStepDetail], optional

        :param time_to_interactive: Time before starting the step.
        :type time_to_interactive: float, optional

        :param type: Step type used in your Synthetic test.
        :type type: SyntheticsStepType, optional

        :param url: URL to perform the step against.
        :type url: str, optional

        :param value: Value for the step.
        :type value: bool, date, datetime, dict, float, int, list, str, none_type, optional

        :param vitals_metrics: Array of Core Web Vitals metrics for the step.
        :type vitals_metrics: [SyntheticsCoreWebVitals], optional

        :param warnings: Warning collected that didn't failed the step.
        :type warnings: [SyntheticsStepDetailWarning], optional
        """
        if browser_errors is not unset:
            kwargs["browser_errors"] = browser_errors
        if check_type is not unset:
            kwargs["check_type"] = check_type
        if description is not unset:
            kwargs["description"] = description
        if duration is not unset:
            kwargs["duration"] = duration
        if error is not unset:
            kwargs["error"] = error
        if playing_tab is not unset:
            kwargs["playing_tab"] = playing_tab
        if screenshot_bucket_key is not unset:
            kwargs["screenshot_bucket_key"] = screenshot_bucket_key
        if skipped is not unset:
            kwargs["skipped"] = skipped
        if snapshot_bucket_key is not unset:
            kwargs["snapshot_bucket_key"] = snapshot_bucket_key
        if step_id is not unset:
            kwargs["step_id"] = step_id
        if sub_test_step_details is not unset:
            kwargs["sub_test_step_details"] = sub_test_step_details
        if time_to_interactive is not unset:
            kwargs["time_to_interactive"] = time_to_interactive
        if type is not unset:
            kwargs["type"] = type
        if url is not unset:
            kwargs["url"] = url
        if value is not unset:
            kwargs["value"] = value
        if vitals_metrics is not unset:
            kwargs["vitals_metrics"] = vitals_metrics
        if warnings is not unset:
            kwargs["warnings"] = warnings
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class DashboardListDeleteResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "deleted_dashboard_list_id": (int,),
        }

    attribute_map = {
        "deleted_dashboard_list_id": "deleted_dashboard_list_id",
    }

    def __init__(self_, deleted_dashboard_list_id: Union[int, UnsetType] = unset, **kwargs):
        """
        Deleted dashboard details.

        :param deleted_dashboard_list_id: ID of the deleted dashboard list.
        :type deleted_dashboard_list_id: int, optional
        """
        if deleted_dashboard_list_id is not unset:
            kwargs["deleted_dashboard_list_id"] = deleted_dashboard_list_id
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class WidgetLineWidth(ModelSimple):
    """
    Width of line displayed.

    :param value: Must be one of ["normal", "thick", "thin"].
    :type value: str
    """

    allowed_values = {
        "normal",
        "thick",
        "thin",
    }
    NORMAL: ClassVar["WidgetLineWidth"]
    THICK: ClassVar["WidgetLineWidth"]
    THIN: ClassVar["WidgetLineWidth"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


WidgetLineWidth.NORMAL = WidgetLineWidth("normal")
WidgetLineWidth.THICK = WidgetLineWidth("thick")
WidgetLineWidth.THIN = WidgetLineWidth("thin")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.sensitive_data_scanner_group_item import SensitiveDataScannerGroupItem


class SensitiveDataScannerGroupList(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.sensitive_data_scanner_group_item import SensitiveDataScannerGroupItem

        return {
            "data": ([SensitiveDataScannerGroupItem],),
        }

    attribute_map = {
        "data": "data",
    }

    def __init__(self_, data: Union[List[SensitiveDataScannerGroupItem], UnsetType] = unset, **kwargs):
        """
        List of groups, ordered.

        :param data: List of groups. The order is important.
        :type data: [SensitiveDataScannerGroupItem], optional
        """
        if data is not unset:
            kwargs["data"] = data
        super().__init__(kwargs)



"""
Delete an application key for this service account returns "No Content" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.service_accounts_api import ServiceAccountsApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ServiceAccountsApi(api_client)
    api_instance.delete_service_account_application_key(
        service_account_id="00000000-0000-1234-0000-000000000000",
        app_key_id="app_key_id",
    )



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class MetricCustomTimeAggregation(ModelSimple):
    """
    A time aggregation for use in query.

    :param value: Must be one of ["avg", "count", "max", "min", "sum"].
    :type value: str
    """

    allowed_values = {
        "avg",
        "count",
        "max",
        "min",
        "sum",
    }
    AVG: ClassVar["MetricCustomTimeAggregation"]
    COUNT: ClassVar["MetricCustomTimeAggregation"]
    MAX: ClassVar["MetricCustomTimeAggregation"]
    MIN: ClassVar["MetricCustomTimeAggregation"]
    SUM: ClassVar["MetricCustomTimeAggregation"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


MetricCustomTimeAggregation.AVG = MetricCustomTimeAggregation("avg")
MetricCustomTimeAggregation.COUNT = MetricCustomTimeAggregation("count")
MetricCustomTimeAggregation.MAX = MetricCustomTimeAggregation("max")
MetricCustomTimeAggregation.MIN = MetricCustomTimeAggregation("min")
MetricCustomTimeAggregation.SUM = MetricCustomTimeAggregation("sum")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class SearchSLOResponseMetaPage(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "first_number": (int,),
            "last_number": (int,),
            "next_number": (int,),
            "number": (int,),
            "prev_number": (int,),
            "size": (int,),
            "total": (int,),
            "type": (str,),
        }

    attribute_map = {
        "first_number": "first_number",
        "last_number": "last_number",
        "next_number": "next_number",
        "number": "number",
        "prev_number": "prev_number",
        "size": "size",
        "total": "total",
        "type": "type",
    }

    def __init__(
        self_,
        first_number: Union[int, UnsetType] = unset,
        last_number: Union[int, UnsetType] = unset,
        next_number: Union[int, UnsetType] = unset,
        number: Union[int, UnsetType] = unset,
        prev_number: Union[int, UnsetType] = unset,
        size: Union[int, UnsetType] = unset,
        total: Union[int, UnsetType] = unset,
        type: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Pagination metadata returned by the API.

        :param first_number: The first number.
        :type first_number: int, optional

        :param last_number: The last number.
        :type last_number: int, optional

        :param next_number: The next number.
        :type next_number: int, optional

        :param number: The page number.
        :type number: int, optional

        :param prev_number: The previous page number.
        :type prev_number: int, optional

        :param size: The size of the response.
        :type size: int, optional

        :param total: The total number of SLOs in the response.
        :type total: int, optional

        :param type: Type of pagination.
        :type type: str, optional
        """
        if first_number is not unset:
            kwargs["first_number"] = first_number
        if last_number is not unset:
            kwargs["last_number"] = last_number
        if next_number is not unset:
            kwargs["next_number"] = next_number
        if number is not unset:
            kwargs["number"] = number
        if prev_number is not unset:
            kwargs["prev_number"] = prev_number
        if size is not unset:
            kwargs["size"] = size
        if total is not unset:
            kwargs["total"] = total
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)



"""
Create a new role by cloning an existing role returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.roles_api import RolesApi
from datadog_api_client.v2.model.role_clone import RoleClone
from datadog_api_client.v2.model.role_clone_attributes import RoleCloneAttributes
from datadog_api_client.v2.model.role_clone_request import RoleCloneRequest
from datadog_api_client.v2.model.roles_type import RolesType

# there is a valid "role" in the system
ROLE_DATA_ID = environ["ROLE_DATA_ID"]

body = RoleCloneRequest(
    data=RoleClone(
        attributes=RoleCloneAttributes(
            name="Example-Create_a_new_role_by_cloning_an_existing_role_returns_OK_response clone",
        ),
        type=RolesType.ROLES,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = RolesApi(api_client)
    response = api_instance.clone_role(role_id=ROLE_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class UsageLogsByRetentionHour(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "indexed_events_count": (int,),
            "live_indexed_events_count": (int,),
            "org_name": (str,),
            "public_id": (str,),
            "rehydrated_indexed_events_count": (int,),
            "retention": (str,),
        }

    attribute_map = {
        "indexed_events_count": "indexed_events_count",
        "live_indexed_events_count": "live_indexed_events_count",
        "org_name": "org_name",
        "public_id": "public_id",
        "rehydrated_indexed_events_count": "rehydrated_indexed_events_count",
        "retention": "retention",
    }

    def __init__(
        self_,
        indexed_events_count: Union[int, UnsetType] = unset,
        live_indexed_events_count: Union[int, UnsetType] = unset,
        org_name: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        rehydrated_indexed_events_count: Union[int, UnsetType] = unset,
        retention: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The number of indexed logs for each hour for a given organization broken down by retention period.

        :param indexed_events_count: Total logs indexed with this retention period during a given hour.
        :type indexed_events_count: int, optional

        :param live_indexed_events_count: Live logs indexed with this retention period during a given hour.
        :type live_indexed_events_count: int, optional

        :param org_name: The organization name.
        :type org_name: str, optional

        :param public_id: The organization public ID.
        :type public_id: str, optional

        :param rehydrated_indexed_events_count: Rehydrated logs indexed with this retention period during a given hour.
        :type rehydrated_indexed_events_count: int, optional

        :param retention: The retention period in days or "custom" for all custom retention usage.
        :type retention: str, optional
        """
        if indexed_events_count is not unset:
            kwargs["indexed_events_count"] = indexed_events_count
        if live_indexed_events_count is not unset:
            kwargs["live_indexed_events_count"] = live_indexed_events_count
        if org_name is not unset:
            kwargs["org_name"] = org_name
        if public_id is not unset:
            kwargs["public_id"] = public_id
        if rehydrated_indexed_events_count is not unset:
            kwargs["rehydrated_indexed_events_count"] = rehydrated_indexed_events_count
        if retention is not unset:
            kwargs["retention"] = retention
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.metrics_query_metadata import MetricsQueryMetadata


class MetricsQueryResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.metrics_query_metadata import MetricsQueryMetadata

        return {
            "error": (str,),
            "from_date": (int,),
            "group_by": ([str],),
            "message": (str,),
            "query": (str,),
            "res_type": (str,),
            "series": ([MetricsQueryMetadata],),
            "status": (str,),
            "to_date": (int,),
        }

    attribute_map = {
        "error": "error",
        "from_date": "from_date",
        "group_by": "group_by",
        "message": "message",
        "query": "query",
        "res_type": "res_type",
        "series": "series",
        "status": "status",
        "to_date": "to_date",
    }
    read_only_vars = {
        "error",
        "from_date",
        "group_by",
        "message",
        "query",
        "res_type",
        "series",
        "status",
        "to_date",
    }

    def __init__(
        self_,
        error: Union[str, UnsetType] = unset,
        from_date: Union[int, UnsetType] = unset,
        group_by: Union[List[str], UnsetType] = unset,
        message: Union[str, UnsetType] = unset,
        query: Union[str, UnsetType] = unset,
        res_type: Union[str, UnsetType] = unset,
        series: Union[List[MetricsQueryMetadata], UnsetType] = unset,
        status: Union[str, UnsetType] = unset,
        to_date: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        Response Object that includes your query and the list of metrics retrieved.

        :param error: Message indicating the errors if status is not ``ok``.
        :type error: str, optional

        :param from_date: Start of requested time window, milliseconds since Unix epoch.
        :type from_date: int, optional

        :param group_by: List of tag keys on which to group.
        :type group_by: [str], optional

        :param message: Message indicating ``success`` if status is ``ok``.
        :type message: str, optional

        :param query: Query string
        :type query: str, optional

        :param res_type: Type of response.
        :type res_type: str, optional

        :param series: List of timeseries queried.
        :type series: [MetricsQueryMetadata], optional

        :param status: Status of the query.
        :type status: str, optional

        :param to_date: End of requested time window, milliseconds since Unix epoch.
        :type to_date: int, optional
        """
        if error is not unset:
            kwargs["error"] = error
        if from_date is not unset:
            kwargs["from_date"] = from_date
        if group_by is not unset:
            kwargs["group_by"] = group_by
        if message is not unset:
            kwargs["message"] = message
        if query is not unset:
            kwargs["query"] = query
        if res_type is not unset:
            kwargs["res_type"] = res_type
        if series is not unset:
            kwargs["series"] = series
        if status is not unset:
            kwargs["status"] = status
        if to_date is not unset:
            kwargs["to_date"] = to_date
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_time import WidgetTime
    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
    from datadog_api_client.v1.model.alert_graph_widget_definition_type import AlertGraphWidgetDefinitionType
    from datadog_api_client.v1.model.widget_viz_type import WidgetVizType


class AlertGraphWidgetDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_time import WidgetTime
        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
        from datadog_api_client.v1.model.alert_graph_widget_definition_type import AlertGraphWidgetDefinitionType
        from datadog_api_client.v1.model.widget_viz_type import WidgetVizType

        return {
            "alert_id": (str,),
            "time": (WidgetTime,),
            "title": (str,),
            "title_align": (WidgetTextAlign,),
            "title_size": (str,),
            "type": (AlertGraphWidgetDefinitionType,),
            "viz_type": (WidgetVizType,),
        }

    attribute_map = {
        "alert_id": "alert_id",
        "time": "time",
        "title": "title",
        "title_align": "title_align",
        "title_size": "title_size",
        "type": "type",
        "viz_type": "viz_type",
    }

    def __init__(
        self_,
        alert_id: str,
        type: AlertGraphWidgetDefinitionType,
        viz_type: WidgetVizType,
        time: Union[WidgetTime, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        title_align: Union[WidgetTextAlign, UnsetType] = unset,
        title_size: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Alert graphs are timeseries graphs showing the current status of any monitor defined on your system.

        :param alert_id: ID of the alert to use in the widget.
        :type alert_id: str

        :param time: Time setting for the widget.
        :type time: WidgetTime, optional

        :param title: The title of the widget.
        :type title: str, optional

        :param title_align: How to align the text on the widget.
        :type title_align: WidgetTextAlign, optional

        :param title_size: Size of the title.
        :type title_size: str, optional

        :param type: Type of the alert graph widget.
        :type type: AlertGraphWidgetDefinitionType

        :param viz_type: Whether to display the Alert Graph as a timeseries or a top list.
        :type viz_type: WidgetVizType
        """
        if time is not unset:
            kwargs["time"] = time
        if title is not unset:
            kwargs["title"] = title
        if title_align is not unset:
            kwargs["title_align"] = title_align
        if title_size is not unset:
            kwargs["title_size"] = title_size
        super().__init__(kwargs)

        self_.alert_id = alert_id
        self_.type = type
        self_.viz_type = viz_type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelComposed,
    cached_property,
)


class ServiceDefinitionSchema(ModelComposed):
    def __init__(self, **kwargs):
        """
        Service definition schema.

        :param contact: Contact information about the service.
        :type contact: ServiceDefinitionV1Contact, optional

        :param extensions: Extensions to V1 schema.
        :type extensions: {str: (bool, date, datetime, dict, float, int, list, str, none_type,)}, optional

        :param external_resources: A list of external links related to the services.
        :type external_resources: [ServiceDefinitionV1Resource], optional

        :param info: Basic information about a service.
        :type info: ServiceDefinitionV1Info

        :param integrations: Third party integrations that Datadog supports.
        :type integrations: ServiceDefinitionV1Integrations, optional

        :param org: Org related information about the service.
        :type org: ServiceDefinitionV1Org, optional

        :param schema_version: Schema version being used.
        :type schema_version: ServiceDefinitionV1Version

        :param tags: A set of custom tags.
        :type tags: [str], optional

        :param contacts: A list of contacts related to the services.
        :type contacts: [ServiceDefinitionV2Contact], optional

        :param dd_service: Unique identifier of the service. Must be unique across all services and is used to match with a service in Datadog.
        :type dd_service: str

        :param dd_team: Experimental feature. A Team handle that matches a Team in the Datadog Teams product.
        :type dd_team: str, optional

        :param docs: A list of documentation related to the services.
        :type docs: [ServiceDefinitionV2Doc], optional

        :param links: A list of links related to the services.
        :type links: [ServiceDefinitionV2Link], optional

        :param repos: A list of code repositories related to the services.
        :type repos: [ServiceDefinitionV2Repo], optional

        :param team: Team that owns the service.
        :type team: str, optional
        """
        super().__init__(kwargs)

    @cached_property
    def _composed_schemas(_):
        # we need this here to make our import statements work
        # we must store _composed_schemas in here so the code is only run
        # when we invoke this method. If we kept this at the class
        # level we would get an error because the class level
        # code would be run when this module is imported, and these composed
        # classes don't exist yet because their module has not finished
        # loading
        from datadog_api_client.v2.model.service_definition_v1 import ServiceDefinitionV1
        from datadog_api_client.v2.model.service_definition_v2 import ServiceDefinitionV2

        return {
            "oneOf": [
                ServiceDefinitionV1,
                ServiceDefinitionV2,
            ],
        }



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.host_map_request import HostMapRequest


class HostMapWidgetDefinitionRequests(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.host_map_request import HostMapRequest

        return {
            "fill": (HostMapRequest,),
            "size": (HostMapRequest,),
        }

    attribute_map = {
        "fill": "fill",
        "size": "size",
    }

    def __init__(
        self_, fill: Union[HostMapRequest, UnsetType] = unset, size: Union[HostMapRequest, UnsetType] = unset, **kwargs
    ):
        """
        List of definitions.

        :param fill: Updated host map.
        :type fill: HostMapRequest, optional

        :param size: Updated host map.
        :type size: HostMapRequest, optional
        """
        if fill is not unset:
            kwargs["fill"] = fill
        if size is not unset:
            kwargs["size"] = size
        super().__init__(kwargs)



"""
Get a list of Audit Logs events returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.audit_api import AuditApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = AuditApi(api_client)
    response = api_instance.list_audit_logs()

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


class ApplicationKeyCreateAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "name": (str,),
            "scopes": ([str], none_type),
        }

    attribute_map = {
        "name": "name",
        "scopes": "scopes",
    }

    def __init__(self_, name: str, scopes: Union[List[str], none_type, UnsetType] = unset, **kwargs):
        """
        Attributes used to create an application Key.

        :param name: Name of the application key.
        :type name: str

        :param scopes: Array of scopes to grant the application key. This feature is in private beta, please contact Datadog support to enable scopes for your application keys.
        :type scopes: [str], none_type, optional
        """
        if scopes is not unset:
            kwargs["scopes"] = scopes
        super().__init__(kwargs)

        self_.name = name



"""
Create a ci-pipelines monitor returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.monitors_api import MonitorsApi
from datadog_api_client.v1.model.monitor import Monitor
from datadog_api_client.v1.model.monitor_options import MonitorOptions
from datadog_api_client.v1.model.monitor_thresholds import MonitorThresholds
from datadog_api_client.v1.model.monitor_type import MonitorType

body = Monitor(
    name="Example-Create_a_ci_pipelines_monitor_returns_OK_response",
    type=MonitorType.CI_PIPELINES_ALERT,
    query='ci-pipelines("ci_level:pipeline @git.branch:staging* @ci.status:error").rollup("count").by("@git.branch,@ci.pipeline.name").last("5m") >= 1',
    message="some message Notify: @hipchat-channel",
    tags=[
        "test:examplecreateacipipelinesmonitorreturnsokresponse",
        "env:ci",
    ],
    priority=3,
    options=MonitorOptions(
        thresholds=MonitorThresholds(
            critical=1.0,
        ),
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = MonitorsApi(api_client)
    response = api_instance.create_monitor(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.aws_logs_lambda import AWSLogsLambda


class AWSLogsListResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.aws_logs_lambda import AWSLogsLambda

        return {
            "account_id": (str,),
            "lambdas": ([AWSLogsLambda],),
            "services": ([str],),
        }

    attribute_map = {
        "account_id": "account_id",
        "lambdas": "lambdas",
        "services": "services",
    }

    def __init__(
        self_,
        account_id: Union[str, UnsetType] = unset,
        lambdas: Union[List[AWSLogsLambda], UnsetType] = unset,
        services: Union[List[str], UnsetType] = unset,
        **kwargs,
    ):
        """
        A list of all Datadog-AWS logs integrations available in your Datadog organization.

        :param account_id: Your AWS Account ID without dashes.
        :type account_id: str, optional

        :param lambdas: List of ARNs configured in your Datadog account.
        :type lambdas: [AWSLogsLambda], optional

        :param services: Array of services IDs.
        :type services: [str], optional
        """
        if account_id is not unset:
            kwargs["account_id"] = account_id
        if lambdas is not unset:
            kwargs["lambdas"] = lambdas
        if services is not unset:
            kwargs["services"] = services
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class MonitorType(ModelNormal):
    validations = {
        "group_status": {
            "inclusive_maximum": 2147483647,
        },
    }
    _nullable = True

    @cached_property
    def openapi_types(_):
        return {
            "created_at": (int,),
            "group_status": (int,),
            "groups": ([str],),
            "id": (int,),
            "message": (str,),
            "modified": (int,),
            "name": (str,),
            "query": (str,),
            "tags": ([str],),
            "templated_name": (str,),
            "type": (str,),
        }

    attribute_map = {
        "created_at": "created_at",
        "group_status": "group_status",
        "groups": "groups",
        "id": "id",
        "message": "message",
        "modified": "modified",
        "name": "name",
        "query": "query",
        "tags": "tags",
        "templated_name": "templated_name",
        "type": "type",
    }

    def __init__(
        self_,
        created_at: Union[int, UnsetType] = unset,
        group_status: Union[int, UnsetType] = unset,
        groups: Union[List[str], UnsetType] = unset,
        id: Union[int, UnsetType] = unset,
        message: Union[str, UnsetType] = unset,
        modified: Union[int, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        query: Union[str, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        templated_name: Union[str, UnsetType] = unset,
        type: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Attributes from the monitor that triggered the event.

        :param created_at: The POSIX timestamp of the monitor's creation in nanoseconds.
        :type created_at: int, optional

        :param group_status: Monitor group status used when there is no ``result_groups``.
        :type group_status: int, optional

        :param groups: Groups to which the monitor belongs.
        :type groups: [str], optional

        :param id: The monitor ID.
        :type id: int, optional

        :param message: The monitor message.
        :type message: str, optional

        :param modified: The monitor's last-modified timestamp.
        :type modified: int, optional

        :param name: The monitor name.
        :type name: str, optional

        :param query: The query that triggers the alert.
        :type query: str, optional

        :param tags: A list of tags attached to the monitor.
        :type tags: [str], optional

        :param templated_name: The templated name of the monitor before resolving any template variables.
        :type templated_name: str, optional

        :param type: The monitor type.
        :type type: str, optional
        """
        if created_at is not unset:
            kwargs["created_at"] = created_at
        if group_status is not unset:
            kwargs["group_status"] = group_status
        if groups is not unset:
            kwargs["groups"] = groups
        if id is not unset:
            kwargs["id"] = id
        if message is not unset:
            kwargs["message"] = message
        if modified is not unset:
            kwargs["modified"] = modified
        if name is not unset:
            kwargs["name"] = name
        if query is not unset:
            kwargs["query"] = query
        if tags is not unset:
            kwargs["tags"] = tags
        if templated_name is not unset:
            kwargs["templated_name"] = templated_name
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)



"""
Search events returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.events_api import EventsApi
from datadog_api_client.v2.model.events_list_request import EventsListRequest
from datadog_api_client.v2.model.events_query_filter import EventsQueryFilter
from datadog_api_client.v2.model.events_request_page import EventsRequestPage
from datadog_api_client.v2.model.events_sort import EventsSort

body = EventsListRequest(
    filter=EventsQueryFilter(
        query="datadog-agent",
        _from="2020-09-17T11:48:36+01:00",
        to="2020-09-17T12:48:36+01:00",
    ),
    sort=EventsSort.TIMESTAMP_ASCENDING,
    page=EventsRequestPage(
        limit=5,
    ),
)

configuration = Configuration()
configuration.unstable_operations["search_events"] = True
with ApiClient(configuration) as api_client:
    api_instance = EventsApi(api_client)
    response = api_instance.search_events(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class HTTPLogError(ModelNormal):
    validations = {
        "code": {
            "inclusive_maximum": 2147483647,
        },
    }

    @cached_property
    def openapi_types(_):
        return {
            "code": (int,),
            "message": (str,),
        }

    attribute_map = {
        "code": "code",
        "message": "message",
    }

    def __init__(self_, code: int, message: str, **kwargs):
        """
        Invalid query performed.

        :param code: Error code.
        :type code: int

        :param message: Error message.
        :type message: str
        """
        super().__init__(kwargs)

        self_.code = code
        self_.message = message



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.slo_correction_category import SLOCorrectionCategory


class SLOCorrectionCreateRequestAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.slo_correction_category import SLOCorrectionCategory

        return {
            "category": (SLOCorrectionCategory,),
            "description": (str,),
            "duration": (int,),
            "end": (int,),
            "rrule": (str,),
            "slo_id": (str,),
            "start": (int,),
            "timezone": (str,),
        }

    attribute_map = {
        "category": "category",
        "description": "description",
        "duration": "duration",
        "end": "end",
        "rrule": "rrule",
        "slo_id": "slo_id",
        "start": "start",
        "timezone": "timezone",
    }

    def __init__(
        self_,
        category: SLOCorrectionCategory,
        slo_id: str,
        start: int,
        description: Union[str, UnsetType] = unset,
        duration: Union[int, UnsetType] = unset,
        end: Union[int, UnsetType] = unset,
        rrule: Union[str, UnsetType] = unset,
        timezone: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The attribute object associated with the SLO correction to be created.

        :param category: Category the SLO correction belongs to.
        :type category: SLOCorrectionCategory

        :param description: Description of the correction being made.
        :type description: str, optional

        :param duration: Length of time (in seconds) for a specified ``rrule`` recurring SLO correction.
        :type duration: int, optional

        :param end: Ending time of the correction in epoch seconds.
        :type end: int, optional

        :param rrule: The recurrence rules as defined in the iCalendar RFC 5545. The supported rules for SLO corrections
            are ``FREQ`` , ``INTERVAL`` , ``COUNT`` and ``UNTIL``.
        :type rrule: str, optional

        :param slo_id: ID of the SLO that this correction applies to.
        :type slo_id: str

        :param start: Starting time of the correction in epoch seconds.
        :type start: int

        :param timezone: The timezone to display in the UI for the correction times (defaults to "UTC").
        :type timezone: str, optional
        """
        if description is not unset:
            kwargs["description"] = description
        if duration is not unset:
            kwargs["duration"] = duration
        if end is not unset:
            kwargs["end"] = end
        if rrule is not unset:
            kwargs["rrule"] = rrule
        if timezone is not unset:
            kwargs["timezone"] = timezone
        super().__init__(kwargs)

        self_.category = category
        self_.slo_id = slo_id
        self_.start = start
